@@ -37,7 +37,6 @@
 
 #include <ticonv.h>
 #include "ticalcs.h"
-#include "internal.h"
 #include "gettext.h"
 #include "logging.h"
 #include "error.h"
@@ -59,17 +58,17 @@ static int		is_ready	(CalcHandle* handle)
 {
 	uint16_t status;
 
-	TRYF(ti73_send_RDY(handle));
-	TRYF(ti73_recv_ACK(handle, &status));
+	TRYF(ti73_send_RDY());
+	TRYF(ti73_recv_ACK(&status));
 
 	return (MSB(status) & 0x01) ? ERR_NOT_READY : 0;
 }
 
 static int		send_key	(CalcHandle* handle, uint16_t key)
 {
-	TRYF(ti73_send_KEY(handle, key));
-	TRYF(ti73_recv_ACK(handle, &key));	// when the key is received
-	TRYF(ti73_recv_ACK(handle, NULL));	// after it completes the resulting action
+	TRYF(ti73_send_KEY(key));
+	TRYF(ti73_recv_ACK(&key));	// when the key is received
+	TRYF(ti73_recv_ACK(NULL));	// after it completes the resulting action
 
 	return 0;
 }
@@ -117,12 +116,12 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 	sc->clipped_width = TI73_COLS;
 	sc->clipped_height = TI73_ROWS;
 
-	TRYF(ti73_send_SCR(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_SCR());
+	TRYF(ti73_recv_ACK(NULL));
 
-	err = ti73_recv_XDP(handle, &max_cnt, buf);	// pb with checksum
+	err = ti73_recv_XDP(&max_cnt, buf);	// pb with checksum
 	if (err != ERR_CHECKSUM) { TRYF(err) };
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_send_ACK());
 
 	*bitmap = (uint8_t *)g_malloc(TI73_COLS * TI73_ROWS / 8);
 	if(*bitmap == NULL)
@@ -152,12 +151,12 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	ti->type = VAR_NODE_NAME;
 	(*vars)->data = ti;
 
-	TRYF(ti73_send_REQ(handle, 0x0000, TI73_DIR, "", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ(0x0000, TI73_DIR, "", 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_XDP(handle, &unused, (uint8_t *)&memory));
+	TRYF(ti73_recv_XDP(&unused, (uint8_t *)&memory));
 	fixup(memory);
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_send_ACK());
 	ti->mem_free = memory;
 
 	folder = g_node_new(NULL);
@@ -197,9 +196,9 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 		int err;
 		uint16_t ve_size;
 
-		err = ti73_recv_VAR(handle, &ve_size, &ve->type, ve->name, &ve->attr);
+		err = ti73_recv_VAR(&ve_size, &ve->type, ve->name, &ve->attr);
 		ve->size = ve_size;
-		TRYF(ti73_send_ACK(handle));
+		TRYF(ti73_send_ACK());
 		if (err == ERR_EOT)
 			break;
 		else if (err != 0)
@@ -224,7 +223,7 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 		g_snprintf(update_->text, sizeof(update_->text), _("Parsing %s"), utf8);
 		g_free(utf8);
 		update_label();
-	}
+  }
 
 	return 0;
 }
@@ -234,12 +233,12 @@ static int		get_memfree	(CalcHandle* handle, uint32_t* ram, uint32_t* flash)
 	uint16_t unused;
 	uint32_t memory;
 
-	TRYF(ti73_send_REQ(handle, 0x0000, TI73_DIR, "", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ(0x0000, TI73_DIR, "", 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_XDP(handle, &unused, (uint8_t *)&memory));
+	TRYF(ti73_recv_XDP(&unused, (uint8_t *)&memory));
 	fixup(memory);
-	TRYF(ti73_send_EOT(handle));
+	TRYF(ti73_send_EOT());
 	*ram = memory;
 	*flash = -1;
 
@@ -260,11 +259,11 @@ static int		send_backup	(CalcHandle* handle, BackupContent* content)
 	varname[4] = LSB(content->mem_address);
 	varname[5] = MSB(content->mem_address);
 
-	TRYF(ti73_send_RTS(handle, content->data_length1, TI73_BKUP, varname, 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_RTS(content->data_length1, TI73_BKUP, varname, 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_SKP(handle, &rej_code))
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_SKP(&rej_code))
+    TRYF(ti73_send_ACK());
 	switch (rej_code) 
 	{
 	case REJ_EXIT:
@@ -280,22 +279,22 @@ static int		send_backup	(CalcHandle* handle, BackupContent* content)
 	update_->max2 = 3;
 	update_->pbar();
 
-	TRYF(ti73_send_XDP(handle, content->data_length1, content->data_part1));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_XDP(content->data_length1, content->data_part1));
+	TRYF(ti73_recv_ACK(NULL));
 	update_->cnt2++;
 	update_->pbar();
 
-	TRYF(ti73_send_XDP(handle, content->data_length2, content->data_part2));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_XDP(content->data_length2, content->data_part2));
+	TRYF(ti73_recv_ACK(NULL));
 	update_->cnt2++;
 	update_->pbar();
 
-	TRYF(ti73_send_XDP(handle, content->data_length3, content->data_part3));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_XDP(content->data_length3, content->data_part3));
+	TRYF(ti73_recv_ACK(NULL));
 	update_->cnt2++;
 	update_->pbar();
 
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_send_ACK());
 
 	return 0;
 }
@@ -308,37 +307,37 @@ static int		recv_backup	(CalcHandle* handle, BackupContent* content)
 	content->model = handle->model;
 	strcpy(content->comment, tifiles_comment_set_backup());
 
-	TRYF(ti73_send_REQ(handle, 0x0000, TI73_BKUP, "", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ(0x0000, TI73_BKUP, "", 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_VAR(handle, &content->data_length1, &content->type, varname, &attr));
-	content->data_length2 = (uint16_t)varname[0] | (((uint16_t)(varname[1])) << 8);
-	content->data_length3 = (uint16_t)varname[2] | (((uint16_t)(varname[3])) << 8);
-	content->mem_address  = (uint16_t)varname[4] | (((uint16_t)(varname[5])) << 8);
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_VAR(&content->data_length1, &content->type, varname, &attr));
+	content->data_length2 = (uint8_t)varname[0] | ((uint8_t)varname[1] << 8);
+	content->data_length3 = (uint8_t)varname[2] | ((uint8_t)varname[3] << 8);
+	content->mem_address  = (uint8_t)varname[4] | ((uint8_t)varname[5] << 8);
+	TRYF(ti73_send_ACK());
 
-	TRYF(ti73_send_CTS(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_CTS());
+	TRYF(ti73_recv_ACK(NULL));
 
 	update_->cnt2 = 0;
 	update_->max2 = 3;
 	update_->pbar();
 
 	content->data_part1 = tifiles_ve_alloc_data(65536);
-	TRYF(ti73_recv_XDP(handle, &content->data_length1, content->data_part1));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_XDP(&content->data_length1, content->data_part1));
+	TRYF(ti73_send_ACK());
 	update_->cnt2++;
 	update_->pbar();
 
 	content->data_part2 = tifiles_ve_alloc_data(65536);
-	TRYF(ti73_recv_XDP(handle, &content->data_length2, content->data_part2));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_XDP(&content->data_length2, content->data_part2));
+	TRYF(ti73_send_ACK());
 	update_->cnt2++;
 	update_->pbar();
 
 	content->data_part3 = tifiles_ve_alloc_data(65536);
-	TRYF(ti73_recv_XDP(handle, &content->data_length3, content->data_part3));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_XDP(&content->data_length3, content->data_part3));
+	TRYF(ti73_send_ACK());
 	update_->cnt2++;
 	update_->pbar();
   
@@ -363,11 +362,11 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 		if(entry->action == ACT_SKIP)
 			continue;
 
-		TRYF(ti73_send_RTS(handle, (uint16_t)entry->size, entry->type, entry->name, entry->attr));
-		TRYF(ti73_recv_ACK(handle, NULL));
+		TRYF(ti73_send_RTS((uint16_t)entry->size, entry->type, entry->name, entry->attr));
+		TRYF(ti73_recv_ACK(NULL));
 
-		TRYF(ti73_recv_SKP(handle, &rej_code));
-		TRYF(ti73_send_ACK(handle));
+		TRYF(ti73_recv_SKP(&rej_code));
+		TRYF(ti73_send_ACK());
 
 		switch (rej_code) 
 		{
@@ -386,10 +385,10 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 		g_free(utf8);
 		update_label();
 
-		TRYF(ti73_send_XDP(handle, entry->size, entry->data));
-		TRYF(ti73_recv_ACK(handle, NULL));
+		TRYF(ti73_send_XDP(entry->size, entry->data));
+		TRYF(ti73_recv_ACK(NULL));
 
-		TRYF(ti73_send_EOT(handle));
+		TRYF(ti73_send_EOT());
 		ticalcs_info("");
 
 		update_->cnt2 = i+1;
@@ -402,38 +401,38 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 
 static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, VarRequest* vr)
 {
-	VarEntry *ve;
-	char *utf8;
-	uint16_t ve_size;
+    VarEntry *ve;
+    char *utf8;
+    uint16_t ve_size;
 
-	content->model = handle->model;
+    content->model = handle->model;
 	strcpy(content->comment, tifiles_comment_set_single());
-	content->num_entries = 1;
+    content->num_entries = 1;
 
-	content->entries = tifiles_ve_create_array(1);
-	ve = content->entries[0] = tifiles_ve_create();
-	memcpy(ve, vr, sizeof(VarEntry));
+    content->entries = tifiles_ve_create_array(1);	
+    ve = content->entries[0] = tifiles_ve_create();
+    memcpy(ve, vr, sizeof(VarEntry));
 
-	utf8 = ticonv_varname_to_utf8(handle->model, vr->name, vr->type);
-	g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
+    utf8 = ticonv_varname_to_utf8(handle->model, vr->name, vr->type);
+    g_snprintf(update_->text, sizeof(update_->text), "%s", utf8);
 	g_free(utf8);
-	update_label();
+    update_label();
 
-	// silent request
-	TRYF(ti73_send_REQ(handle, (uint16_t)vr->size, vr->type, vr->name, vr->attr));
-	TRYF(ti73_recv_ACK(handle, NULL));
+    // silent request
+    TRYF(ti73_send_REQ((uint16_t)vr->size, vr->type, vr->name, vr->attr));
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_VAR(handle, &ve_size, &ve->type, ve->name, &vr->attr));
-	ve->size = ve_size;
-	TRYF(ti73_send_ACK(handle));
+    TRYF(ti73_recv_VAR(&ve_size, &ve->type, ve->name, &vr->attr));
+    ve->size = ve_size;
+    TRYF(ti73_send_ACK());
 
-	TRYF(ti73_send_CTS(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+    TRYF(ti73_send_CTS());
+    TRYF(ti73_recv_ACK(NULL));
 
-	ve->data = tifiles_ve_alloc_data(ve->size);
-	TRYF(ti73_recv_XDP(handle, &ve_size, ve->data));
-	ve->size = ve_size;
-	TRYF(ti73_send_ACK(handle));
+    ve->data = tifiles_ve_alloc_data(ve->size);
+    TRYF(ti73_recv_XDP(&ve_size, ve->data));
+    ve->size = ve_size;
+    TRYF(ti73_send_ACK());
 
 	return 0;
 }
@@ -475,13 +474,26 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 	// check for 83+ Silver Edition (not usable in boot mode, sic!)
 	if(handle->model != CALC_TI73 && ptr->data_type == TI83p_APPL)
 	{
-		CalcInfos infos;
+		CalcInfos infos = { 0 };
 
 		TRYF(get_version(handle, &infos));
 		se = infos.hw_version & 1;
 	}
 
+#if 0
+	printf("size = %08x\n", ptr->data_length);
+	printf("#pages: %i\n", ptr->num_pages);
+	printf("type: %02x\n", ptr->data_type);
+	for (i = 0; i < ptr->num_pages; i++) 
+	{
+		FlashPage *fp = ptr->pages[i];
 
+		printf("page #%i: %04x %02x %02x %04x\n", i,
+			fp->addr, fp->page, fp->flag, fp->size);		
+	}
+
+	return 0;
+#endif
 
 	ticalcs_info(_("FLASH name: \"%s\""), ptr->name);
 	ticalcs_info(_("FLASH size: %i bytes."), ptr->data_length);
@@ -506,17 +518,17 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 			uint16_t addr = fp->addr + j;
 			uint8_t* data = fp->data + j;
 
-			TRYF(ti73_send_VAR2(handle, size, ptr->data_type, fp->flag, addr, fp->page));
-			TRYF(ti73_recv_ACK(handle, NULL));
+			TRYF(ti73_send_VAR2(size, ptr->data_type, fp->flag, addr, fp->page));
+			TRYF(ti73_recv_ACK(NULL));
 
 			if(handle->model == CALC_TI73 && ptr->data_type == TI83p_APPL)
-				{TRYF(ti73_recv_CTS(handle, 0));}	// is depending of OS version?
+				{TRYF(ti73_recv_CTS(0));}	// is depending of OS version?
 			else
-				{TRYF(ti73_recv_CTS(handle, 10));}
-			TRYF(ti73_send_ACK(handle));
+				{TRYF(ti73_recv_CTS(10));}
+			TRYF(ti73_send_ACK());
 
-			TRYF(ti73_send_XDP(handle, size, data));
-			TRYF(ti73_recv_ACK(handle, NULL));
+			TRYF(ti73_send_XDP(size, data));
+			TRYF(ti73_recv_ACK(NULL));
 
 			update_->cnt2 += size;
 			update_->pbar();
@@ -535,8 +547,8 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		}
 	}
 
-	TRYF(ti73_send_EOT(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_EOT());
+	TRYF(ti73_recv_ACK(NULL));
 
 	return 0;
 }
@@ -571,8 +583,8 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 	page = 0;
 	fp = content->pages[page] = tifiles_fp_create();
 
-	TRYF(ti73_send_REQ2(handle, 0x00, TI73_APPL, vr->name, 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ2(0x00, TI73_APPL, vr->name, 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
 	update_->cnt2 = 0;
 	update_->max2 = vr->size;
@@ -582,8 +594,8 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 		int err;
 		char name[9];
 
-		err = ti73_recv_VAR2(handle, &data_length, &data_type, name, &data_addr, &data_page);
-		TRYF(ti73_send_ACK(handle));
+		err = ti73_recv_VAR2(&data_length, &data_type, name, &data_addr, &data_page);
+		TRYF(ti73_send_ACK());
 		if (err == ERR_EOT)
 			goto exit;
 		TRYF(err);
@@ -600,7 +612,7 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 			fp->addr = data_addr & 0x4000;
 			fp->page = old_page;
 			fp->flag = 0x80;
-			fp->size = offset;
+			fp->size = offset;			
 			fp->data = tifiles_fp_alloc_data(FLASH_PAGE_SIZE);
 			memcpy(fp->data, buf, fp->size);
 
@@ -611,11 +623,11 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 			fp = content->pages[page] = tifiles_fp_create();
 		}
 
-		TRYF(ti73_send_CTS(handle));
-		TRYF(ti73_recv_ACK(handle, NULL));
+		TRYF(ti73_send_CTS());
+		TRYF(ti73_recv_ACK(NULL));
 
-		TRYF(ti73_recv_XDP(handle, &data_length, &buf[offset]));
-		TRYF(ti73_send_ACK(handle));
+		TRYF(ti73_recv_XDP((uint16_t *)&data_length, &buf[offset]));
+		TRYF(ti73_send_ACK());
 
 		if (first_block)
 		{
@@ -624,7 +636,7 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 			/* compute actual application size */
 			if (buf[0] == 0x80 && buf[1] == 0x0f)
 			{
-				uint32_t len = ((uint32_t)(buf[2])) << 24 | ((uint32_t)(buf[3])) << 16 | ((uint32_t)(buf[4])) << 8 | (uint32_t)(buf[5]);
+				uint32_t len = buf[2] << 24 | buf[3] << 16 | buf[4] << 8 | buf[5];
 				update_->max2 = len + 75;
 			}
 		}
@@ -641,7 +653,7 @@ exit:
 		fp->addr = data_addr & 0x4000;
 		fp->page = old_page;
 		fp->flag = 0x80;
-		fp->size = offset;
+		fp->size = offset;			
 		fp->data = tifiles_fp_alloc_data(FLASH_PAGE_SIZE);
 		memcpy(fp->data, buf, fp->size);
 		page++;
@@ -665,17 +677,17 @@ static int		recv_idlist	(CalcHandle* handle, uint8_t* id)
 	g_snprintf(update_->text, sizeof(update_->text), "ID-LIST");
 	update_label();
 
-	TRYF(ti73_send_REQ(handle, 0x0000, TI73_IDLIST, "", 0x00));
-	TRYF(ti73_recv_ACK(handle, &unused));
+	TRYF(ti73_send_REQ(0x0000, TI73_IDLIST, "", 0x00));
+	TRYF(ti73_recv_ACK(&unused));
 
-	TRYF(ti73_recv_VAR(handle, &varsize, &vartype, varname, &varattr));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_VAR(&varsize, &vartype, varname, &varattr));
+	TRYF(ti73_send_ACK());
 
-	TRYF(ti73_send_CTS(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_CTS());
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_XDP(handle, &varsize, data));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_XDP(&varsize, data));
+	TRYF(ti73_send_ACK());
 
 	i = data[9];
 	data[9] = data[10];
@@ -692,65 +704,62 @@ static int		dump_rom_1	(CalcHandle* handle)
 {
 	// Send dumping program
 	if(handle->model == CALC_TI73)
-	{
-		TRYF(rd_send(handle, "romdump.73p", romDumpSize73, romDump73));
-	}
+		{ TRYF(rd_send(handle, "romdump.73p", romDumpSize73, romDump73)); }
 	else
-	{
 		TRYF(rd_send(handle, "romdump.8Xp", romDumpSize8Xp, romDump8Xp));
-	}
 
 	return 0;
 }
 
 static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filename)
 {
-	static const uint16_t keys_83p[] = {
+	int err, i;
+	static const uint16_t keys[] = { 
 		0x40, 0x09, 0x09, 0xFC9C, /* Quit, Clear, Clear, Asm( */
 		0xDA, 0xAB, 0xA8, 0xA6,   /* prgm, R, O, M */
 		0x9D, 0xAE, 0xA6, 0xA9,   /* D, U, M, P */
 		0x86, 0x05 };             /* ), Enter */
 
-	static const uint16_t keys_73[] = {
-		0x40, 0x09, 0x09, 0xDA,   /* Quit, Clear, Clear, prgm */
-		0xAB, 0xA8, 0xA6, 0x9D,   /* R, O, M, D, */
-		0xAE, 0xA6, 0xA9, 0x05 }; /* U, M, P, Enter */
-
-	const uint16_t *keys;
-	int nkeys, i;
-
-	if (handle->model == CALC_TI73)
+	// Launch program by remote control
+	if (handle->model != CALC_TI73)
 	{
-		keys = keys_73;
-		nkeys = G_N_ELEMENTS(keys_73);
+		// Launch program by remote control
+		PAUSE(200);
+		for(i = 0; i < (int)(sizeof(keys) / sizeof(keys[0])) - 1; i++)
+		{
+			TRYF(send_key(handle, keys[i]));
+			PAUSE(100);
+		}
+
+		// This fixes a 100% reproducable timeout: send_key normally requests an ACK,
+		// but when the program is running, no ACK is sent. Therefore, hit the Enter key
+		// without requesting an ACK.
+		TRYF(ti73_send_KEY(keys[i]));
+		TRYF(ti73_recv_ACK(NULL)); // when the key is received
+		PAUSE(200);
 	}
 	else
 	{
-		keys = keys_83p;
-		nkeys = G_N_ELEMENTS(keys_83p);
-	}
+		// else wait for user's action
+		sprintf(update_->text, _("Waiting for user's action..."));
+		update_label();
 
-	// Launch program by remote control
-	PAUSE(200);
-	for(i = 0; i < nkeys - 1; i++)
-	{
-		TRYF(send_key(handle, keys[i]));
-		PAUSE(100);
+		do
+		{
+			handle->updat->refresh();
+			if (handle->updat->cancel)
+				return ERR_ABORT;
+			
+			//send RDY request ???
+			PAUSE(1000);
+			err = rd_is_ready(handle);
+		}
+		while (err == ERROR_READ_TIMEOUT);
 	}
 
-	// This fixes a 100% reproducable timeout: send_key normally requests an ACK,
-	// but when the program is running, no ACK is sent. Therefore, hit the Enter key
-	// without requesting an ACK.
-	TRYF(ti73_send_KEY(handle, keys[i]));
-	TRYF(ti73_recv_ACK(handle, NULL)); // when the key is received
-	PAUSE(200);
-
 	// Get dump
 	TRYF(rd_dump(handle, filename));
 
-	// (Normally there would be another ACK after the program exits,
-	// but the ROM dumper disables that behavior)
-
 	return 0;
 }
 
@@ -779,7 +788,7 @@ static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
 
 	cur.tm_year = _clock->year - 1900;
 	cur.tm_mon = _clock->month - 1;
-	cur.tm_mday = _clock->day;
+	cur.tm_mday = _clock->day;	
 	cur.tm_hour = _clock->hours;
 	cur.tm_min = _clock->minutes;
 	cur.tm_sec = _clock->seconds;
@@ -789,27 +798,27 @@ static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
 	
 	calc_time = (uint32_t)difftime(c, r);
 
-	buffer[2] = MSB(MSW(calc_time));
-	buffer[3] = LSB(MSW(calc_time));
-	buffer[4] = MSB(LSW(calc_time));
-	buffer[5] = LSB(LSW(calc_time));
-	buffer[6] = _clock->date_format;
-	buffer[7] = _clock->time_format;
-	buffer[8] = 0xff;
+    buffer[2] = MSB(MSW(calc_time));
+    buffer[3] = LSB(MSW(calc_time));
+    buffer[4] = MSB(LSW(calc_time));
+    buffer[5] = LSB(LSW(calc_time));
+    buffer[6] = _clock->date_format;
+    buffer[7] = _clock->time_format;
+    buffer[8] = 0xff;
 
-	g_snprintf(update_->text, sizeof(update_->text), _("Setting clock..."));
-	update_label();
+    g_snprintf(update_->text, sizeof(update_->text), _("Setting clock..."));
+    update_label();
 
-	TRYF(ti73_send_RTS(handle, 13, TI73_CLK, "\0x08", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_RTS(13, TI73_CLK, "\0x08", 0x00));
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_CTS(handle, 13));
-	TRYF(ti73_send_ACK(handle));
+    TRYF(ti73_recv_CTS(13));
+    TRYF(ti73_send_ACK());
 
-	TRYF(ti73_send_XDP(handle, 9, buffer));
-	TRYF(ti73_recv_ACK(handle, NULL));
+    TRYF(ti73_send_XDP(9, buffer));
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_send_EOT(handle));
+    TRYF(ti73_send_EOT());
 
 	return 0;
 }
@@ -817,31 +826,31 @@ static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
 static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 {
 	uint16_t varsize;
-	uint8_t vartype;
+    uint8_t vartype;
 	uint8_t varattr;
-	char varname[9];
-	uint8_t buffer[32];
+    char varname[9];
+    uint8_t buffer[32];
 	uint32_t calc_time;
 
 	struct tm ref, *cur;
 	time_t r, c, now;
 
-	g_snprintf(update_->text, sizeof(update_->text), _("Getting clock..."));
-	update_label();
+    g_snprintf(update_->text, sizeof(update_->text), _("Getting clock..."));
+    update_label();
 
-	TRYF(ti73_send_REQ(handle, 0x0000, TI73_CLK, "\0x08", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ(0x0000, TI73_CLK, "\0x08", 0x00));
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_VAR(handle, &varsize, &vartype, varname, &varattr));
-	TRYF(ti73_send_ACK(handle));
+    TRYF(ti73_recv_VAR(&varsize, &vartype, varname, &varattr));
+    TRYF(ti73_send_ACK());
 
-	TRYF(ti73_send_CTS(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+    TRYF(ti73_send_CTS());
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_XDP(handle, &varsize, buffer));
-	TRYF(ti73_send_ACK(handle));
+    TRYF(ti73_recv_XDP(&varsize, buffer));
+    TRYF(ti73_send_ACK());
 
-	calc_time = (((uint32_t)(buffer[2])) << 24) | (((uint32_t)(buffer[3])) << 16) | (((uint32_t)(buffer[4])) << 8) | (uint32_t)(buffer[5]);
+	calc_time = (buffer[2] << 24) | (buffer[3] << 16) | (buffer[4] << 8) | buffer[5];
 	//printf("<%08x>\n", time);
 
 	time(&now);	// retrieve current DST setting
@@ -869,22 +878,12 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 	_clock->minutes = cur->tm_min;
 	_clock->seconds = cur->tm_sec;
 
-	_clock->date_format = buffer[6];
-	_clock->time_format = buffer[7];
+    _clock->date_format = buffer[6];
+    _clock->time_format = buffer[7];
 
 	return 0;
 }
 
-static int		rename_var	(CalcHandle* handle, VarRequest* oldname, VarRequest* newname)
-{
-	return 0;
-}
-
-static int		change_attr	(CalcHandle* handle, VarRequest* vr, FileAttr attr)
-{
-	return 0;
-}
-
 static int		del_var		(CalcHandle* handle, VarRequest* vr)
 {
 	char *utf8;
@@ -894,9 +893,9 @@ static int		del_var		(CalcHandle* handle, VarRequest* vr)
 	g_free(utf8);
 	update_label();
 
-	TRYF(ti73_send_DEL(handle, (uint16_t)vr->size, vr->type, vr->name, vr->attr));
-	TRYF(ti73_recv_ACK(handle, NULL));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_DEL((uint16_t)vr->size, vr->type, vr->name, vr->attr));
+	TRYF(ti73_recv_ACK(NULL));
+	TRYF(ti73_recv_ACK(NULL));
 
 	return 0;
 }
@@ -911,14 +910,14 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	uint16_t length;
 	uint8_t buf[32];
 
-	TRYF(ti73_send_VER(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_VER());
+	TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_send_CTS(handle));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_CTS());
+    TRYF(ti73_recv_ACK(NULL));
 
-	TRYF(ti73_recv_XDP(handle, &length, buf));
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_recv_XDP(&length, buf));
+    TRYF(ti73_send_ACK());
 
 	memset(infos, 0, sizeof(CalcInfos));
 	if(handle->model == CALC_TI73)
@@ -939,8 +938,6 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	case 1: infos->model = CALC_TI83P; break;
 	case 2: infos->model = CALC_TI84P; break;
 	case 3: infos->model = CALC_TI84P; break;
-	case 5: infos->model = CALC_TI84P; break; // 84+CSE
-	default: infos->model = CALC_TI84P; break; // If new models ever arise, they'll probably be 84+ anyway.
 	}
 	infos->language_id = buf[6];
 	infos->sub_lang_id = buf[7];
@@ -975,27 +972,27 @@ static int		send_cert	(CalcHandle* handle, FlashContent* content)
 		nblocks = ptr->data_length / size;
 		update_->max2 = nblocks;
 
-		TRYF(ti73_send_VAR2(handle, size, ptr->data_type, 0x04, 0x4000, 0x00));
-		TRYF(ti73_recv_ACK(handle, NULL));
+		TRYF(ti73_send_VAR2(size, ptr->data_type, 0x04, 0x4000, 0x00));
+		TRYF(ti73_recv_ACK(NULL));
 
-		TRYF(ti73_recv_CTS(handle, 10));
-		TRYF(ti73_send_ACK(handle));
+		TRYF(ti73_recv_CTS(10));
+		TRYF(ti73_send_ACK());
 
 		for(i = 0; i <= nblocks; i++) 
 		{
 			uint32_t length = size;
 
-			TRYF(ti73_send_XDP(handle, length, (ptr->data_part) + length * i))
-			TRYF(ti73_recv_ACK(handle, NULL));
+			TRYF(ti73_send_XDP(length, (ptr->data_part) + length * i))
+			TRYF(ti73_recv_ACK(NULL));
 
-			TRYF(ti73_recv_CTS(handle, size));
-			TRYF(ti73_send_ACK(handle));
+			TRYF(ti73_recv_CTS(size));
+			TRYF(ti73_send_ACK());
 
 			update_->cnt2 = i;
 			update_->pbar();
 		}
 
-		TRYF(ti73_send_EOT(handle));
+		TRYF(ti73_send_EOT());
 
 		ticalcs_info(_("Header sent completely."));
 
@@ -1018,23 +1015,23 @@ static int		recv_cert	(CalcHandle* handle, FlashContent* content)
 	content->num_pages = 0;
 	content->data_part = (uint8_t *)tifiles_ve_alloc_data(2 * 1024 * 1024);	// 2MB max
 
-	TRYF(ti73_send_REQ2(handle, 0x00, TI83p_GETCERT, "", 0x00));
-	TRYF(ti73_recv_ACK(handle, NULL));
+	TRYF(ti73_send_REQ2(0x00, TI83p_GETCERT, "", 0x00));
+	TRYF(ti73_recv_ACK(NULL));
 
 	TRYF(ticables_cable_recv(handle->cable, buf, 4));	//VAR w/ no header
 	ticalcs_info(" TI->PC: VAR");
-	TRYF(ti73_send_ACK(handle));
+	TRYF(ti73_send_ACK());
 
 	for(i = 0, content->data_length = 0;; i++) 
 	{
 		int err;
 		uint16_t block_size;
 
-		TRYF(ti73_send_CTS(handle));
-		TRYF(ti73_recv_ACK(handle, NULL));
+		TRYF(ti73_send_CTS());
+		TRYF(ti73_recv_ACK(NULL));
 
-		err = ti73_recv_XDP(handle, &block_size, content->data_part);
-		TRYF(ti73_send_ACK(handle));
+		err = ti73_recv_XDP(&block_size, content->data_part);
+		TRYF(ti73_send_ACK());
 
 		content->data_length += block_size;
 
@@ -1059,33 +1056,8 @@ const CalcFncts calc_73 =
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_ROMDUMP | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_MEMFREE | FTS_FLASH | FTS_BACKUP,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P",   /* send_backup */
-	 "2P",   /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P", "2P", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P1L", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1107,12 +1079,10 @@ const CalcFncts calc_73 =
 	&set_clock,
 	&get_clock,
 	&del_var,
-	&new_folder,
-	&get_version,
+        &new_folder,
+        &get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
 
 const CalcFncts calc_83p = 
@@ -1124,33 +1094,8 @@ const CalcFncts calc_83p =
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_ROMDUMP | OPS_DELVAR | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_MEMFREE | FTS_FLASH | FTS_CERT | FTS_BACKUP,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P",   /* send_backup */
-	 "2P",   /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P", "2P", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1176,8 +1121,6 @@ const CalcFncts calc_83p =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
 
 const CalcFncts calc_84p = 
@@ -1189,33 +1132,8 @@ const CalcFncts calc_84p =
 	OPS_ISREADY | OPS_KEYS | OPS_SCREEN | OPS_DIRLIST | OPS_BACKUP | OPS_VARS | 
 	OPS_FLASH | OPS_IDLIST | OPS_ROMDUMP | OPS_CLOCK | OPS_DELVAR | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_MEMFREE | FTS_FLASH | FTS_CERT | FTS_BACKUP,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P",   /* send_backup */
-	 "2P",   /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P", "2P", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1241,6 +1159,4 @@ const CalcFncts calc_84p =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
