@@ -35,7 +35,6 @@
 
 #include <ticonv.h>
 #include "ticalcs.h"
-#include "internal.h"
 #include "gettext.h"
 #include "logging.h"
 #include "error.h"
@@ -58,16 +57,16 @@ static int		is_ready	(CalcHandle* handle)
 {
 	uint16_t status;
 
-	TRYF(ti89_send_RDY(handle));
-	TRYF(ti89_recv_ACK(handle, &status));
+	TRYF(ti89_send_RDY());
+	TRYF(ti89_recv_ACK(&status));
 
 	return (MSB(status) & 0x01) ? ERR_NOT_READY : 0;
 }
 
 static int		send_key	(CalcHandle* handle, uint16_t key)
 {
-	TRYF(ti89_send_KEY(handle, key));
-	TRYF(ti89_recv_ACK(handle, &key));
+	TRYF(ti89_send_KEY(key));
+	TRYF(ti89_recv_ACK(&key));
 	PAUSE(50);
 
 	return 0;
@@ -146,12 +145,12 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 		break;
 	}
 
-	TRYF(ti89_send_SCR(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_SCR());
+	TRYF(ti89_recv_ACK(NULL));
 
-	err = ti89_recv_XDP(handle, &max_cnt, buf);	// pb with checksum
+	err = ti89_recv_XDP(&max_cnt, buf);	// pb with checksum
 	if(err != ERR_CHECKSUM) { TRYF(err) };
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_send_ACK());
 
 	*bitmap = (uint8_t *)g_malloc(TI89_COLS * TI89_ROWS / 8);
 	if(*bitmap == NULL) 
@@ -197,20 +196,20 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	root = g_node_new(NULL);
 	g_node_append(*apps, root);
 
-    TRYF(ti89_send_REQ(handle, TI89_FDIR << 24, TI89_RDIR, ""));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_REQ(TI89_FDIR << 24, TI89_RDIR, ""));
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_recv_VAR(handle, &info.size, &info.type, info.name));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_VAR(&info.size, &info.type, info.name));
+    TRYF(ti89_send_ACK());
 
-    TRYF(ti89_send_CTS(handle));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_CTS());
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_recv_XDP(handle, &block_size, buffer));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_XDP(&block_size, buffer));
+    TRYF(ti89_send_ACK());
 
-    TRYF(ti89_recv_EOT(handle));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_EOT());
+    TRYF(ti89_send_ACK());
 
 	for(j = 4; j < (int)block_size;) 
 	{
@@ -252,20 +251,20 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 
 		ticalcs_info(_("Directory listing in %8s..."), folder_name);
 
-		TRYF(ti89_send_REQ(handle, TI89_LDIR << 24, TI89_RDIR, folder_name));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_REQ(TI89_LDIR << 24, TI89_RDIR, folder_name));
+		TRYF(ti89_recv_ACK(NULL));
 
-		TRYF(ti89_recv_VAR(handle, &info.size, &info.type, info.name));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_VAR(&info.size, &info.type, info.name));
+		TRYF(ti89_send_ACK());
 
-		TRYF(ti89_send_CTS(handle));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_CTS());
+		TRYF(ti89_recv_ACK(NULL));
 
-		TRYF(ti89_recv_XDP(handle, &block_size, buffer));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_XDP(&block_size, buffer));
+		TRYF(ti89_send_ACK());
 
-		TRYF(ti89_recv_EOT(handle));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_EOT());
+		TRYF(ti89_send_ACK());
 
 		for(j = 4 + 14 + extra; j < (int)block_size;) 
 		{
@@ -375,18 +374,18 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 		case ATTRB_ARCHIVED: vartype = 0x27; break;
 		}
 
-		TRYF(ti89_send_RTS(handle, entry->size, vartype, varname));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_RTS(entry->size, vartype, varname));
+		TRYF(ti89_recv_ACK(NULL));
 
-		TRYF(ti89_recv_CTS(handle));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_CTS());
+		TRYF(ti89_send_ACK());
 
 		memcpy(buffer + 4, entry->data, entry->size);
-		TRYF(ti89_send_XDP(handle, entry->size + 4, buffer));
-		TRYF(ti89_recv_ACK(handle, &status));
+		TRYF(ti89_send_XDP(entry->size + 4, buffer));
+		TRYF(ti89_recv_ACK(&status));
 
-		TRYF(ti89_send_EOT(handle));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_EOT());
+		TRYF(ti89_recv_ACK(NULL));
 
 		update_->cnt2 = i+1;
 		update_->max2 = content->num_entries;
@@ -413,24 +412,24 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 	g_free(utf8);
 	update_label();
 
-	TRYF(ti89_send_REQ(handle, 0, vr->type, varname));
-	TRYF(ti89_recv_ACK(handle, &status));
+	TRYF(ti89_send_REQ(0, vr->type, varname));
+	TRYF(ti89_recv_ACK(&status));
 	if(status != 0)
 		return ERR_MISSING_VAR;
 
-	TRYF(ti89_recv_VAR(handle, &ve->size, &ve->type, ve->name));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_VAR(&ve->size, &ve->type, ve->name));
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_send_CTS(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_CTS());
+	TRYF(ti89_recv_ACK(NULL));
 
 	ve->data = tifiles_ve_alloc_data(ve->size + 4);
-	TRYF(ti89_recv_XDP(handle, &unused, ve->data));
+	TRYF(ti89_recv_XDP(&unused, ve->data));
 	memmove(ve->data, ve->data + 4, ve->size);
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_recv_EOT(handle));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_EOT());
+	TRYF(ti89_send_ACK());
 
 	PAUSE(250);
 
@@ -442,14 +441,14 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 static int		send_backup	(CalcHandle* handle, BackupContent* content)
 {
 	// erase memory
-	TRYF(ti89_send_VAR(handle, 0, TI89_BKUP, "main"));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_VAR(0, TI89_BKUP, "main"));
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_CTS(handle));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_CTS());
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_send_EOT(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_EOT());
+	TRYF(ti89_recv_ACK(NULL));
 
 	// next, send var(s)
 	TRYF(send_var(handle, MODE_BACKUP, (FileContent *)content));
@@ -492,18 +491,18 @@ static int		send_var_ns	(CalcHandle* handle, CalcMode mode, FileContent* content
 		g_free(utf8);
 		update_label();
 
-		TRYF(ti89_send_VAR(handle, entry->size, vartype, varname));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_VAR(entry->size, vartype, varname));
+		TRYF(ti89_recv_ACK(NULL));
 
-		TRYF(ti89_recv_CTS(handle));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_CTS());
+		TRYF(ti89_send_ACK());
 
 		memcpy(buffer + 4, entry->data, entry->size);
-		TRYF(ti89_send_XDP(handle, entry->size + 4, buffer));
-		TRYF(ti89_recv_ACK(handle, &status));
+		TRYF(ti89_send_XDP(entry->size + 4, buffer));
+		TRYF(ti89_recv_ACK(&status));
 
-		TRYF(ti89_send_EOT(handle));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_EOT());
+		TRYF(ti89_recv_ACK(NULL));
 
 		if(mode & MODE_BACKUP) 
 		{
@@ -535,8 +534,8 @@ static int		recv_var_ns	(CalcHandle* handle, CalcMode mode, FileContent* content
 		ve = content->entries[nvar-1] = tifiles_ve_create();
 		strcpy(ve->folder, "main");	
 
-		err = ti89_recv_VAR(handle, &ve->size, &ve->type, tipath);
-		TRYF(ti89_send_ACK(handle));
+		err = ti89_recv_VAR(&ve->size, &ve->type, tipath);
+		TRYF(ti89_send_ACK());
 
 		if(err == ERR_EOT)	// end of transmission
 			goto exit;
@@ -561,13 +560,13 @@ static int		recv_var_ns	(CalcHandle* handle, CalcMode mode, FileContent* content
 		g_free(utf8);
 		update_label();
 
-		TRYF(ti89_send_CTS(handle));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_CTS());
+		TRYF(ti89_recv_ACK(NULL));
 
 		ve->data = tifiles_ve_alloc_data(ve->size + 4);
-		TRYF(ti89_recv_XDP(handle, &unused, ve->data));
+		TRYF(ti89_recv_XDP(&unused, ve->data));
 		memmove(ve->data, ve->data + 4, ve->size);
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_send_ACK());
 	}
 
 exit:
@@ -604,16 +603,16 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		{
 		  if(handle->model == CALC_TI89T || handle->model == CALC_V200)
 		  {
-			TRYF(ti89_send_RTS2(handle, ptr->data_length, ptr->data_type, ptr->hw_id));
+			TRYF(ti89_send_RTS2(ptr->data_length, ptr->data_type, ptr->hw_id));
 		  }
 		  else
 		  {
-			TRYF(ti89_send_RTS(handle, ptr->data_length, ptr->data_type, ""));
+			TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ""));
 		  }
 		} 
 		else 
 		{
-			TRYF(ti89_send_RTS(handle, ptr->data_length, ptr->data_type, ptr->name));
+			TRYF(ti89_send_RTS(ptr->data_length, ptr->data_type, ptr->name));
 		}
 
 		nblocks = ptr->data_length / 65536;
@@ -623,28 +622,28 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		{
 			uint32_t length = (i != nblocks) ? 65536 : ptr->data_length % 65536;
 
-			TRYF(ti89_recv_ACK(handle, NULL));
+			TRYF(ti89_recv_ACK(NULL));
 
-			TRYF(ti89_recv_CTS(handle));
-			TRYF(ti89_send_ACK(handle));
+			TRYF(ti89_recv_CTS());
+			TRYF(ti89_send_ACK());
 
-			TRYF(ti89_send_XDP(handle, length, (ptr->data_part) + 65536 * i));
-			TRYF(ti89_recv_ACK(handle, NULL));
+			TRYF(ti89_send_XDP(length, (ptr->data_part) + 65536 * i));
+			TRYF(ti89_recv_ACK(NULL));
 
 			if(i != nblocks) 
 			{
-			  TRYF(ti89_send_CNT(handle));
+			  TRYF(ti89_send_CNT());
 			} 
 			else 
 			{
-			  TRYF(ti89_send_EOT(handle));
+			  TRYF(ti89_send_EOT());
 			}
 
 			update_->cnt2 = i;
 			update_->pbar();
 		}
 
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_recv_ACK(NULL));
 		ticalcs_info(_("Header sent completely."));
 	}
 
@@ -673,10 +672,10 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 	default: return ERR_FATAL_ERROR;
 	}
 
-	TRYF(ti89_send_REQ(handle, 0x00, vr->type, vr->name));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_REQ(0x00, vr->type, vr->name));
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_VAR(handle, &content->data_length, &content->data_type, content->name));
+	TRYF(ti89_recv_VAR(&content->data_length, &content->data_type, content->name));
 
 	update_->cnt2 = 0;
 	update_->max2 = vr->size;
@@ -686,17 +685,17 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 		int err;
 		uint32_t block_size;
 
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_send_ACK());
 
-		TRYF(ti89_send_CTS(handle));
-		TRYF(ti89_recv_ACK(handle, NULL));
+		TRYF(ti89_send_CTS());
+		TRYF(ti89_recv_ACK(NULL));
 
-		TRYF(ti89_recv_XDP(handle, &block_size, content->data_part + content->data_length));
-		TRYF(ti89_send_ACK(handle));
+		TRYF(ti89_recv_XDP(&block_size, content->data_part + content->data_length));
+		TRYF(ti89_send_ACK());
 
 		content->data_length += block_size;
 
-		err = ti89_recv_CNT(handle);
+		err = ti89_recv_CNT();
 		if(err == ERR_EOT)
 			break;
 		TRYF(err);
@@ -705,7 +704,7 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 		update_->pbar();
 	}
 
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_send_ACK());
 
 	return 0;
 }
@@ -719,22 +718,22 @@ static int		recv_idlist	(CalcHandle* handle, uint8_t* idlist)
 	g_snprintf(update_->text, sizeof(update_->text), "ID-LIST");
 	update_label();
 
-	TRYF(ti89_send_REQ(handle, 0x0000, TI89_IDLIST, ""));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_REQ(0x0000, TI89_IDLIST, ""));
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_VAR(handle, &varsize, &vartype, varname));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_VAR(&varsize, &vartype, varname));
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_send_CTS(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_CTS());
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_XDP(handle, &varsize, idlist));
+	TRYF(ti89_recv_XDP(&varsize, idlist));
 	memcpy(idlist, idlist+8, varsize - 8);
 	idlist[varsize - 8] = '\0';
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_recv_EOT(handle));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_EOT());
+	TRYF(ti89_send_ACK());
 
 	return 0;
 }
@@ -811,17 +810,17 @@ static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
     g_snprintf(update_->text, sizeof(update_->text), _("Setting clock..."));
     update_label();
 
-    TRYF(ti89_send_RTS(handle, 0x10, TI89_CLK, "Clock"));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_RTS(0x10, TI89_CLK, "Clock"));
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_recv_CTS(handle));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_CTS());
+    TRYF(ti89_send_ACK());
 
-    TRYF(ti89_send_XDP(handle, 0x10, buffer));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_XDP(0x10, buffer));
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_send_EOT(handle));
-    TRYF(ti89_recv_ACK(handle, &status));
+    TRYF(ti89_send_EOT());
+    TRYF(ti89_recv_ACK(&status));
 
 	return 0;
 }
@@ -836,20 +835,20 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
     g_snprintf(update_->text, sizeof(update_->text), _("Getting clock..."));
     update_label();
 
-    TRYF(ti89_send_REQ(handle, 0x0000, TI89_CLK, "Clock"));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_REQ(0x0000, TI89_CLK, "Clock"));
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_recv_VAR(handle, &varsize, &vartype, varname));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_VAR(&varsize, &vartype, varname));
+    TRYF(ti89_send_ACK());
 
-    TRYF(ti89_send_CTS(handle));
-    TRYF(ti89_recv_ACK(handle, NULL));
+    TRYF(ti89_send_CTS());
+    TRYF(ti89_recv_ACK(NULL));
 
-    TRYF(ti89_recv_XDP(handle, &varsize, buffer));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_XDP(&varsize, buffer));
+    TRYF(ti89_send_ACK());
 
-    TRYF(ti89_recv_EOT(handle));
-    TRYF(ti89_send_ACK(handle));
+    TRYF(ti89_recv_EOT());
+    TRYF(ti89_send_ACK());
 
     _clock->year = (buffer[6] << 8) | buffer[7];
     _clock->month = buffer[8];
@@ -863,16 +862,6 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 	return 0;
 }
 
-static int		rename_var	(CalcHandle* handle, VarRequest* oldname, VarRequest* newname)
-{
-	return 0;
-}
-
-static int		change_attr	(CalcHandle* handle, VarRequest* vr, FileAttr attr)
-{
-	return 0;
-}
-
 static int		del_var		(CalcHandle* handle, VarRequest* vr)
 {
 	char varname[18];
@@ -884,9 +873,9 @@ static int		del_var		(CalcHandle* handle, VarRequest* vr)
 	g_free(utf8);
 	update_label();
 
-	TRYF(ti89_send_DEL(handle, vr->size, vr->type, varname));
-	TRYF(ti89_recv_ACK(handle, NULL));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_DEL(vr->size, vr->type, varname));
+	TRYF(ti89_recv_ACK(NULL));
+	TRYF(ti89_recv_ACK(NULL));
 
 	return 0;
 }
@@ -904,17 +893,17 @@ static int		new_folder  (CalcHandle* handle, VarRequest* vr)
 	update_label();
 
 	// send empty expression
-	TRYF(ti89_send_RTS(handle, 0x10, 0x00, varname));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_RTS(0x10, 0x00, varname));
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_CTS(handle));
-	TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_CTS());
+	TRYF(ti89_send_ACK());
 
-	TRYF(ti89_send_XDP(handle, 0x10, data));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_XDP(0x10, data));
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_send_EOT(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_EOT());
+	TRYF(ti89_recv_ACK(NULL));
 
 	PAUSE(250);
 
@@ -930,14 +919,14 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	uint32_t length;
 	uint8_t buf[32];
 
-	TRYF(ti89_send_VER(handle));
-	TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_VER());
+	TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_send_CTS(handle));
-    TRYF(ti89_recv_ACK(handle, NULL));
+	TRYF(ti89_send_CTS());
+    TRYF(ti89_recv_ACK(NULL));
 
-	TRYF(ti89_recv_XDP(handle, &length, buf));
-    TRYF(ti89_send_ACK(handle));
+	TRYF(ti89_recv_XDP(&length, buf));
+    TRYF(ti89_send_ACK());
 
 	memset(infos, 0, sizeof(CalcInfos));
 	g_snprintf(infos->os_version, 5, "%1i.%02i", buf[0], buf[1]);
@@ -1013,33 +1002,8 @@ const CalcFncts calc_89 =
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION |
 	FTS_SILENT | FTS_FOLDER | FTS_FLASH | FTS_CERT,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P1L", /* send_backup */
-	 "2P1L", /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1065,8 +1029,6 @@ const CalcFncts calc_89 =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
 
 const CalcFncts calc_92p = 
@@ -1079,33 +1041,8 @@ const CalcFncts calc_92p =
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_FOLDER | FTS_FLASH | FTS_CERT,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P1L", /* send_backup */
-	 "2P1L", /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1131,8 +1068,6 @@ const CalcFncts calc_92p =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
 
 const CalcFncts calc_89t = 
@@ -1145,33 +1080,8 @@ const CalcFncts calc_89t =
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP | 
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_FOLDER | FTS_FLASH | FTS_CERT,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P1L", /* send_backup */
-	 "2P1L", /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1197,8 +1107,6 @@ const CalcFncts calc_89t =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
 
 const CalcFncts calc_v2 = 
@@ -1211,33 +1119,8 @@ const CalcFncts calc_v2 =
 	OPS_FLASH | OPS_IDLIST | OPS_CLOCK | OPS_ROMDUMP |
 	OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_OS |
 	FTS_SILENT | FTS_FOLDER | FTS_FLASH | FTS_CERT,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P1L", /* send_backup */
-	 "2P1L", /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1263,6 +1146,4 @@ const CalcFncts calc_v2 =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
