@@ -35,7 +35,6 @@
 
 #include <ticonv.h>
 #include "ticalcs.h"
-#include "internal.h"
 #include "gettext.h"
 #include "logging.h"
 #include "error.h"
@@ -57,10 +56,10 @@
 
 static int		is_ready	(CalcHandle* handle)
 {
-	DUSBModeSet mode = MODE_NORMAL;
+	ModeSet mode = MODE_NORMAL;
 
-	TRYF(dusb_cmd_s_mode_set(handle, mode));
-	TRYF(dusb_cmd_r_mode_ack(handle));
+	TRYF(cmd_s_mode_set(handle, mode));
+	TRYF(cmd_r_mode_ack(handle));
 
 	return 0;
 }
@@ -68,8 +67,8 @@ static int		is_ready	(CalcHandle* handle)
 static int		send_key	(CalcHandle* handle, uint16_t key)
 {
 	PAUSE(25);	// this pause is needed between 2 keys
-	TRYF(dusb_cmd_s_execute(handle, "", "", EID_KEY, "", key));
-	TRYF(dusb_cmd_r_data_ack(handle));
+	TRYF(cmd_s_execute(handle, "", "", EID_KEY, NULL, key));
+	TRYF(cmd_r_data_ack(handle));
 
 	return 0;
 }
@@ -85,8 +84,8 @@ static int		execute		(CalcHandle* handle, VarEntry *ve, const char *args)
 	default:         action = EID_PRGM; break;
 	}
 
-	TRYF(dusb_cmd_s_execute(handle, ve->folder, ve->name, action, args, 0));
-	TRYF(dusb_cmd_r_data_ack(handle));
+	TRYF(cmd_s_execute(handle, ve->folder, ve->name, action, args, 0));
+	TRYF(cmd_r_data_ack(handle));
 
 	return 0;
 }
@@ -94,16 +93,16 @@ static int		execute		(CalcHandle* handle, VarEntry *ve, const char *args)
 static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitmap)
 {
 	uint16_t pid[] = { PID_SCREENSHOT };
-	DUSBCalcParam **param;
+	CalcParam **param;
 
 	sc->width = TI89T_COLS;
 	sc->height = TI89T_ROWS;
 	sc->clipped_width = TI89T_COLS_VISIBLE;
 	sc->clipped_height = TI89T_ROWS_VISIBLE;
     
-	param = dusb_cp_new_array(1);
-	TRYF(dusb_cmd_s_param_request(handle, 1, pid));
-	TRYF(dusb_cmd_r_param_data(handle, 1, param));
+	param = cp_new_array(1);
+	TRYF(cmd_s_param_request(handle, 1, pid));
+	TRYF(cmd_r_param_data(handle, 1, param));
 	if(!param[0]->ok)
 		return ERR_INVALID_PACKET;
 	
@@ -121,7 +120,7 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 				(*bitmap)[i++] = (*bitmap)[j * (TI89T_COLS >> 3) + k];
 	}
 
-	dusb_cp_del_array(1, param);
+	cp_del_array(1, param);
 	return 0;
 }
 
@@ -131,7 +130,7 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	const int size = sizeof(aids) / sizeof(uint16_t);
 	TreeInfo *ti;
 	int err;
-	DUSBCalcAttr **attr;
+	CalcAttr **attr;
 	GNode *root, *folder = NULL;
 	char fldname[40];
 	char varname[40];
@@ -153,14 +152,14 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	root = g_node_new(NULL);
 	g_node_append(*apps, root);
 
-	TRYF(dusb_cmd_s_dirlist_request(handle, size, aids));
+	TRYF(cmd_s_dirlist_request(handle, size, aids));
 	for(;;)
 	{
 		VarEntry *ve = tifiles_ve_create();
 		GNode *node;
 
-		attr = dusb_ca_new_array(size);
-		err = dusb_cmd_r_var_header(handle, fldname, varname, attr);
+		attr = ca_new_array(size);
+		err = cmd_r_var_header(handle, fldname, varname, attr);
 		if (err == ERR_EOT)
 			break;
 		else if (err != 0)
@@ -168,15 +167,10 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 
 		strcpy(ve->folder, fldname);
 		strcpy(ve->name, varname);
-		//ve->size = GINT32_FROM_BE(*((uint32_t *)(attr[3]->data)));
-		ve->size = (  (((uint32_t)(attr[3]->data[0])) << 24)
-		            | (((uint32_t)(attr[3]->data[1])) << 16)
-		            | (((uint32_t)(attr[3]->data[2])) <<  8)
-		            | (((uint32_t)(attr[3]->data[3]))      ));
-		//ve->type = GINT32_FROM_BE(*((uint32_t *)(attr[0]->data))) & 0xff;
-		ve->type = (uint32_t)(attr[0]->data[3]);
+		ve->size = GINT32_FROM_BE(*((uint32_t *)(attr[3]->data)));
+		ve->type = GINT32_FROM_BE(*((uint32_t *)(attr[0]->data))) & 0xff;
 		ve->attr = attr[1]->data[0] ? ATTRB_ARCHIVED : attr[4]->data[0] ? ATTRB_LOCKED : ATTRB_NONE;
-		dusb_ca_del_array(size, attr);
+		ca_del_array(size, attr);
 
 		if(ve->type == TI89_DIR)
 		{
@@ -221,24 +215,16 @@ static int		get_memfree	(CalcHandle* handle, uint32_t* ram, uint32_t* flash)
 {
 	uint16_t pids[] = { PID_FREE_RAM, PID_FREE_FLASH };
 	const int size = sizeof(pids) / sizeof(uint16_t);
-	DUSBCalcParam **params;
+	CalcParam **params;
 
-	params = dusb_cp_new_array(size);
-	TRYF(dusb_cmd_s_param_request(handle, size, pids));
-	TRYF(dusb_cmd_r_param_data(handle, size, params));
+	params = cp_new_array(size);
+	TRYF(cmd_s_param_request(handle, size, pids));
+	TRYF(cmd_r_param_data(handle, size, params));
 
-	//*ram = (uint32_t)GINT64_FROM_BE(*((uint64_t *)(params[0]->data)));
-	*ram = (  (((uint32_t)(params[0]->data[4])) << 24)
-	        | (((uint32_t)(params[0]->data[5])) << 16)
-	        | (((uint32_t)(params[0]->data[6])) <<  8)
-	        | (((uint32_t)(params[0]->data[7]))      ));
-	//*flash = (uint32_t)GINT64_FROM_BE(*((uint64_t *)(params[1]->data)));
-	*flash = (  (((uint32_t)(params[1]->data[4])) << 24)
-	          | (((uint32_t)(params[1]->data[5])) << 16)
-	          | (((uint32_t)(params[1]->data[6])) <<  8)
-	          | (((uint32_t)(params[1]->data[7]))      ));
+	*ram = (uint32_t)GINT64_FROM_BE(*((uint64_t *)(params[0]->data)));
+	*flash = (uint32_t)GINT64_FROM_BE(*((uint64_t *)(params[1]->data)));
 
-	dusb_cp_del_array(size, params);
+	cp_del_array(size, params);
 	return 0;
 }
 
@@ -246,7 +232,7 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 {
 	int i;
 	char *utf8;
-	DUSBCalcAttr **attrs;
+	CalcAttr **attrs;
 	const int nattrs = 4;
 	uint32_t pkt_size;
 
@@ -273,22 +259,22 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 		g_free(utf8);
 		update_label();
 
-		attrs = dusb_ca_new_array(nattrs);
-		attrs[0] = dusb_ca_new(AID_VAR_TYPE, 4);
+		attrs = ca_new_array(nattrs);
+		attrs[0] = ca_new(AID_VAR_TYPE, 4);
 		attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
 		attrs[0]->data[2] = 0x00; attrs[0]->data[3] = ve->type;
-		attrs[1] = dusb_ca_new(AID_ARCHIVED, 1);
+		attrs[1] = ca_new(AID_ARCHIVED, 1);
 		attrs[1]->data[0] = ve->attr == ATTRB_ARCHIVED ? 1 : 0;
-		attrs[2] = dusb_ca_new(AID_VAR_VERSION, 4);
+		attrs[2] = ca_new(AID_VAR_VERSION, 4);
 		attrs[2]->data[0] = 0;
-		attrs[3] = dusb_ca_new(AID_LOCKED, 1);
+		attrs[3] = ca_new(AID_LOCKED, 1);
 		attrs[3]->data[0] = ve->attr == ATTRB_LOCKED ? 1 : 0;
 
 		if(!(ve->size & 1))
 			TRYF(is_ready(handle));
 
-		TRYF(dusb_cmd_s_rts(handle, ve->folder, ve->name, ve->size, nattrs, CA(attrs)));
-		TRYF(dusb_cmd_r_data_ack(handle));
+		TRYF(cmd_s_rts(handle, ve->folder, ve->name, ve->size, nattrs, CA(attrs)));
+		TRYF(cmd_r_data_ack(handle));
 
 		/*
 			When sending variables with an odd varsize, bufer has to be negotiatied again with an even value.
@@ -308,9 +294,9 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 			TRYF(dusb_recv_buf_size_alloc(handle, NULL));
 		}
 
-		TRYF(dusb_cmd_s_var_content(handle, ve->size, ve->data));
-		TRYF(dusb_cmd_r_data_ack(handle));
-		TRYF(dusb_cmd_s_eot(handle));
+		TRYF(cmd_s_var_content(handle, ve->size, ve->data));
+		TRYF(cmd_r_data_ack(handle));
+		TRYF(cmd_s_eot(handle));
 
 		update_->cnt2 = i+1;
 		update_->max2 = content->num_entries;
@@ -326,7 +312,7 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 {
 	uint16_t aids[] = { AID_ARCHIVED, AID_VAR_VERSION, AID_LOCKED };
 	const int naids = sizeof(aids) / sizeof(uint16_t);
-	DUSBCalcAttr **attrs;
+	CalcAttr **attrs;
 	const int nattrs = 1;
 	char fldname[40], varname[40];
 	uint8_t *data;
@@ -338,17 +324,17 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 	g_free(utf8);
 	update_label();
 
-	attrs = dusb_ca_new_array(nattrs);
-	attrs[0] = dusb_ca_new(AID_VAR_TYPE2, 4);
+	attrs = ca_new_array(nattrs);
+	attrs[0] = ca_new(AID_VAR_TYPE2, 4);
 	attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
 	attrs[0]->data[2] = 0x00; attrs[0]->data[3] = vr->type;
 
-	TRYF(dusb_cmd_s_var_request(handle, vr->folder, vr->name, naids, aids, 
+	TRYF(cmd_s_var_request(handle, vr->folder, vr->name, naids, aids, 
 			       nattrs, CA(attrs)));
-	dusb_ca_del_array(nattrs, attrs);
-	attrs = dusb_ca_new_array(naids);
-	TRYF(dusb_cmd_r_var_header(handle, fldname, varname, attrs));
-	TRYF(dusb_cmd_r_var_content(handle, NULL, &data));
+	ca_del_array(nattrs, attrs);
+	attrs = ca_new_array(naids);
+	TRYF(cmd_r_var_header(handle, fldname, varname, attrs));
+	TRYF(cmd_r_var_content(handle, NULL, &data));
 
 	content->model = handle->model;
 	strcpy(content->comment, tifiles_comment_set_single());
@@ -362,7 +348,7 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 	memcpy(ve->data, data, ve->size);
 	g_free(data);	
 
-	dusb_ca_del_array(naids, attrs);
+	ca_del_array(naids, attrs);
 	return 0;
 }
 
@@ -386,7 +372,7 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 {
 	FlashContent *ptr;
 	char *utf8;
-	DUSBCalcAttr **attrs;
+	CalcAttr **attrs;
 	const int nattrs = 4;
 
 	// send all headers except license
@@ -403,23 +389,23 @@ static int		send_flash	(CalcHandle* handle, FlashContent* content)
 		g_free(utf8);
 		update_label();
 
-		attrs = dusb_ca_new_array(nattrs);
-		attrs[0] = dusb_ca_new(AID_VAR_TYPE, 4);
+		attrs = ca_new_array(nattrs);
+		attrs[0] = ca_new(AID_VAR_TYPE, 4);
 		attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
 		attrs[0]->data[2] = 0x00; attrs[0]->data[3] = ptr->data_type;
-		attrs[1] = dusb_ca_new(AID_ARCHIVED, 1);
+		attrs[1] = ca_new(AID_ARCHIVED, 1);
 		attrs[1]->data[0] = 0;
-		attrs[2] = dusb_ca_new(AID_VAR_VERSION, 4);
+		attrs[2] = ca_new(AID_VAR_VERSION, 4);
 		attrs[2]->data[3] = 1;
-		attrs[3] = dusb_ca_new(AID_LOCKED, 1);
+		attrs[3] = ca_new(AID_LOCKED, 1);
 		attrs[3]->data[0] = 0;
 		
-		TRYF(dusb_cmd_s_rts(handle, "", ptr->name, ptr->data_length, 
+		TRYF(cmd_s_rts(handle, "", ptr->name, ptr->data_length, 
 			       nattrs, CA(attrs)));
-		TRYF(dusb_cmd_r_data_ack(handle));
-		TRYF(dusb_cmd_s_var_content(handle, ptr->data_length, ptr->data_part));
-		TRYF(dusb_cmd_r_data_ack(handle));
-		TRYF(dusb_cmd_s_eot(handle));
+		TRYF(cmd_r_data_ack(handle));
+		TRYF(cmd_s_var_content(handle, ptr->data_length, ptr->data_part));
+		TRYF(cmd_r_data_ack(handle));
+		TRYF(cmd_s_eot(handle));
 	}
 
 	return 0;
@@ -429,7 +415,7 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 {
 	uint16_t aids[] = { AID_ARCHIVED, AID_VAR_VERSION, AID_LOCKED };
 	const int naids = sizeof(aids) / sizeof(uint16_t);
-	DUSBCalcAttr **attrs;
+	CalcAttr **attrs;
 	const int nattrs = 1;
 	char fldname[40], varname[40];
 	uint8_t *data;
@@ -440,17 +426,17 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 	g_free(utf8);
 	update_label();
 
-	attrs = dusb_ca_new_array(nattrs);
-	attrs[0] = dusb_ca_new(AID_VAR_TYPE2, 4);
+	attrs = ca_new_array(nattrs);
+	attrs[0] = ca_new(AID_VAR_TYPE2, 4);
 	attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
 	attrs[0]->data[2] = 0x00; attrs[0]->data[3] = vr->type;
 
-	TRYF(dusb_cmd_s_var_request(handle, "", vr->name, naids, aids, 
+	TRYF(cmd_s_var_request(handle, "", vr->name, naids, aids, 
 			       nattrs, CA(attrs)));
-	dusb_ca_del_array(nattrs, attrs);
-	attrs = dusb_ca_new_array(naids);
-	TRYF(dusb_cmd_r_var_header(handle, fldname, varname, attrs));
-	TRYF(dusb_cmd_r_var_content(handle, NULL, &data));
+	ca_del_array(nattrs, attrs);
+	attrs = ca_new_array(naids);
+	TRYF(cmd_r_var_header(handle, fldname, varname, attrs));
+	TRYF(cmd_r_var_content(handle, NULL, &data));
 
 	content->model = handle->model;
 	strcpy(content->name, vr->name);
@@ -462,13 +448,13 @@ static int		recv_flash	(CalcHandle* handle, FlashContent* content, VarRequest* v
 	memcpy(content->data_part, data, content->data_length);
 	g_free(data);
 
-	dusb_ca_del_array(naids, attrs);
+	ca_del_array(naids, attrs);
 	return 0;
 }
 
 static int		send_os    (CalcHandle* handle, FlashContent* content)
 {
-	DUSBModeSet mode = { 2, 1, 0, 0, 0x0fa0 }; //MODE_BASIC;
+	ModeSet mode = { 2, 1, 0, 0, 0x0fa0 }; //MODE_BASIC;
 	uint32_t pkt_size = 0x3ff;
 	uint32_t hdr_size = 0;
 	uint32_t hdr_offset = 0;
@@ -491,16 +477,16 @@ static int		send_os    (CalcHandle* handle, FlashContent* content)
 	hdr_size = i - hdr_offset - 6;
 
 	// switch to BASIC mode
-	TRYF(dusb_cmd_s_mode_set(handle, mode));
-	TRYF(dusb_cmd_r_mode_ack(handle));
+	TRYF(cmd_s_mode_set(handle, mode));
+	TRYF(cmd_r_mode_ack(handle));
 
 	// start OS transfer
-	TRYF(dusb_cmd_s_os_begin(handle, ptr->data_length));
-	TRYF(dusb_cmd_r_os_ack(handle, &pkt_size));
+	TRYF(cmd_s_os_begin(handle, ptr->data_length));
+	TRYF(cmd_r_os_ack(handle, &pkt_size));
 
 	// send OS header/signature
-	TRYF(dusb_cmd_s_os_header_89(handle, hdr_size, ptr->data_part + hdr_offset));
-	TRYF(dusb_cmd_r_os_ack(handle, &pkt_size));
+	TRYF(cmd_s_os_header_89(handle, hdr_size, ptr->data_part + hdr_offset));
+	TRYF(cmd_r_os_ack(handle, &pkt_size));
 
 	// send OS data
 	q = ptr->data_length / 0x2000;
@@ -511,23 +497,23 @@ static int		send_os    (CalcHandle* handle, FlashContent* content)
 
 	for(i = 0; i < q; i++)
 	{
-		TRYF(dusb_cmd_s_os_data_89(handle, 0x2000, ptr->data_part + i*0x2000));
-		TRYF(dusb_cmd_r_data_ack(handle));
+		TRYF(cmd_s_os_data_89(handle, 0x2000, ptr->data_part + i*0x2000));
+		TRYF(cmd_r_data_ack(handle));
 
 		update_->cnt2 = i;
 		update_->pbar();
 	}
 	{
-		TRYF(dusb_cmd_s_os_data_89(handle, r, ptr->data_part + i*0x2000));
-		TRYF(dusb_cmd_r_data_ack(handle));
+		TRYF(cmd_s_os_data_89(handle, r, ptr->data_part + i*0x2000));
+		TRYF(cmd_r_data_ack(handle));
 
 		update_->cnt2 = i;
 		update_->pbar();
 	}
 	
-	TRYF(dusb_cmd_s_eot(handle));
+	TRYF(cmd_s_eot(handle));
 	PAUSE(500);
-	TRYF(dusb_cmd_r_eot_ack(handle));
+	TRYF(cmd_r_eot_ack(handle));
 
 	return 0;
 }
@@ -535,14 +521,14 @@ static int		send_os    (CalcHandle* handle, FlashContent* content)
 static int		recv_idlist	(CalcHandle* handle, uint8_t* id)
 {
 	uint16_t pid[] = { PID_FULL_ID };
-	DUSBCalcParam **param;
+	CalcParam **param;
 
 	g_snprintf(update_->text, sizeof(update_->text), "ID-LIST");
 	update_label();
 
-	param = dusb_cp_new_array(1);
-	TRYF(dusb_cmd_s_param_request(handle, 1, pid));
-	TRYF(dusb_cmd_r_param_data(handle, 1, param));
+	param = cp_new_array(1);
+	TRYF(cmd_s_param_request(handle, 1, pid));
+	TRYF(cmd_r_param_data(handle, 1, param));
 	if(!param[0]->ok)
 		return ERR_INVALID_PACKET;
 
@@ -556,14 +542,14 @@ static int		recv_idlist	(CalcHandle* handle, uint8_t* id)
 
 static int		dump_rom_1	(CalcHandle* handle)
 {
-	DUSBCalcParam *param;
+	CalcParam *param;
 
 	// Go back to HOME screen
-	param = dusb_cp_new(PID_HOMESCREEN, 1);
+	param = cp_new(PID_HOMESCREEN, 1);
 	param->data[0] = 1;
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
 	// Send dumping program
 	TRYF(rd_send(handle, "romdump.89z", romDumpSize89t, romDump89t));
@@ -594,8 +580,8 @@ static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filen
 	PAUSE(200);
 #endif
 #if 1
-	TRYF(dusb_cmd_s_execute(handle, "main", "romdump", EID_ASM, "", 0));
-	TRYF(dusb_cmd_r_data_ack(handle));
+	TRYF(cmd_s_execute(handle, "main", "romdump", EID_ASM, "", 0));
+	TRYF(cmd_r_data_ack(handle));
 #endif
 
 	// Get dump
@@ -606,7 +592,7 @@ static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filen
 
 static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
 {
-	DUSBCalcParam *param;
+	CalcParam *param;
 
 	uint32_t calc_time;
 	struct tm ref, cur;
@@ -640,32 +626,32 @@ static int		set_clock	(CalcHandle* handle, CalcClock* _clock)
 	g_snprintf(update_->text, sizeof(update_->text), _("Setting clock..."));
 	update_label();
 
-	param = dusb_cp_new(PID_CLK_SEC, 4);
+	param = cp_new(PID_CLK_SEC, 4);
 	param->data[0] = MSB(MSW(calc_time));
 	param->data[1] = LSB(MSW(calc_time));
 	param->data[2] = MSB(LSW(calc_time));
 	param->data[3] = LSB(LSW(calc_time));
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
-	param = dusb_cp_new(PID_CLK_DATE_FMT, 1);
+	param = cp_new(PID_CLK_DATE_FMT, 1);
 	param->data[0] = _clock->date_format == 3 ? 0 : _clock->date_format;
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
-	param = dusb_cp_new(PID_CLK_TIME_FMT, 1);
+	param = cp_new(PID_CLK_TIME_FMT, 1);
 	param->data[0] = _clock->time_format == 24 ? 1 : 0;
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
-	param = dusb_cp_new(PID_CLK_ON, 1);
+	param = cp_new(PID_CLK_ON, 1);
 	param->data[0] = _clock->state;
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
 	return 0;
 }
@@ -674,7 +660,7 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 {
 	uint16_t pids[4] = { PID_CLK_SEC, PID_CLK_DATE_FMT, PID_CLK_TIME_FMT, PID_CLK_ON };
 	const int size = sizeof(pids) / sizeof(uint16_t);
-	DUSBCalcParam **params;
+	CalcParam **params;
 
 	uint32_t calc_time;
 	struct tm ref, *cur;
@@ -684,9 +670,9 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 	g_snprintf(update_->text, sizeof(update_->text), _("Getting clock..."));
 	update_label();
 
-	params = dusb_cp_new_array(size);
-	TRYF(dusb_cmd_s_param_request(handle, size, pids));
-	TRYF(dusb_cmd_r_param_data(handle, size, params));
+	params = cp_new_array(size);
+	TRYF(cmd_s_param_request(handle, size, pids));
+	TRYF(cmd_r_param_data(handle, size, params));
 	if(!params[0]->ok)
 		return ERR_INVALID_PACKET;
 	
@@ -721,106 +707,45 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 	_clock->time_format = params[2]->data[0] ? 24 : 12;
 	_clock->state = params[3]->data[0];
 
-	dusb_cp_del_array(1, params);
+	cp_del_array(1, params);
 
 	return 0;
 }
 
 static int		del_var		(CalcHandle* handle, VarRequest* vr)
 {
-	DUSBCalcAttr **attr;
+	CalcAttr **attr;
 	const int size = 2;
 	char varname[68];
 	char *utf8;
 
 	tifiles_build_fullname(handle->model, varname, vr->folder, vr->name);
-	utf8 = ticonv_varname_to_utf8(handle->model, varname, vr->type);
+	utf8 = ticonv_varname_to_utf8(handle->model, vr->name, vr->type);
 	g_snprintf(update_->text, sizeof(update_->text), _("Deleting %s..."), utf8);
 	g_free(utf8);
 	update_label();
 
-	attr = dusb_ca_new_array(size);
-	attr[0] = dusb_ca_new(AID_VAR_TYPE2, 4);
+	attr = ca_new_array(size);
+	attr[0] = ca_new(AID_VAR_TYPE2, 4);
 	attr[0]->data[0] = 0xF0; attr[0]->data[1] = 0x0C;
 	attr[0]->data[2] = 0x00; attr[0]->data[3] = vr->type;
-	attr[1] = dusb_ca_new(AID_UNKNOWN_13, 1);
+	attr[1] = ca_new(AID_UNKNOWN_13, 1);
 	attr[1]->data[0] = 0;
 
-	TRYF(dusb_cmd_s_var_delete(handle, vr->folder, vr->name, size, CA(attr)));
-	TRYF(dusb_cmd_r_data_ack(handle));
+	TRYF(cmd_s_var_delete(handle, vr->folder, vr->name, size, CA(attr)));
+	TRYF(cmd_r_data_ack(handle));
 
-	dusb_ca_del_array(size, attr);
+	ca_del_array(size, attr);
 	return 0;
 }
 
-static int		rename_var	(CalcHandle* handle, VarRequest* oldname, VarRequest* newname)
-{
-	DUSBCalcAttr **attrs;
-	int ret = 0;
-	char varname1[68], varname2[68];
-	char *utf81, *utf82;
-
-	tifiles_build_fullname(handle->model, varname1, oldname->folder, oldname->name);
-	tifiles_build_fullname(handle->model, varname2, newname->folder, newname->name);
-	utf81 = ticonv_varname_to_utf8(handle->model, varname1, oldname->type);
-	utf82 = ticonv_varname_to_utf8(handle->model, varname2, newname->type);
-	g_snprintf(update_->text, sizeof(update_->text), _("Renaming %s to %s..."), utf81, utf82);
-	g_free(utf81);
-	g_free(utf82);
-	update_label();
-
-	attrs = dusb_ca_new_array(1);
-	attrs[0] = dusb_ca_new(AID_VAR_TYPE2, 4);
-	attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
-	attrs[0]->data[2] = 0x00; attrs[0]->data[3] = oldname->type;
-
-	ret = dusb_cmd_s_var_modify(handle, oldname->folder, oldname->name, 1, CA(attrs), newname->folder, newname->name, 0, NULL);
-	if(!ret)
-		ret = dusb_cmd_r_data_ack(handle);
-
-	dusb_ca_del_array(1, attrs);
-	return ret;
-}
-
-static int		change_attr	(CalcHandle* handle, VarRequest* vr, FileAttr attr)
-{
-	DUSBCalcAttr **srcattrs;
-	DUSBCalcAttr **dstattrs;
-	int ret = 0;
-	char *utf8;
-
-	utf8 = ticonv_varname_to_utf8(handle->model, vr->folder, -1);
-	g_snprintf(update_->text, sizeof(update_->text), _("Changing attributes of %s..."), utf8);
-	g_free(utf8);
-	update_label();
-
-	srcattrs = dusb_ca_new_array(1);
-	srcattrs[0] = dusb_ca_new(AID_VAR_TYPE2, 4);
-	srcattrs[0]->data[0] = 0xF0; srcattrs[0]->data[1] = 0x0C;
-	srcattrs[0]->data[2] = 0x00; srcattrs[0]->data[3] = vr->type;
-
-	dstattrs = dusb_ca_new_array(2);
-	dstattrs[0] = dusb_ca_new(AID_ARCHIVED, 1);
-	dstattrs[0]->data[0] = (attr == ATTRB_ARCHIVED ? 0x01 : 0x00);
-	dstattrs[1] = dusb_ca_new(AID_LOCKED, 1);
-	dstattrs[1]->data[0] = (attr == ATTRB_LOCKED ? 0x01 : 0x00);
-
-	ret = dusb_cmd_s_var_modify(handle, vr->folder, vr->name, 1, CA(srcattrs), vr->folder, vr->name, 2, CA(dstattrs));
-	if(!ret)
-		ret = dusb_cmd_r_data_ack(handle);
-
-	dusb_ca_del_array(1, srcattrs);
-	dusb_ca_del_array(2, dstattrs);
-	return ret;
-}
-
 static int		new_folder  (CalcHandle* handle, VarRequest* vr)
 {
 	uint8_t data[16] = { 0x00, 0x00, 0x00, 0x00, 0x00, 0x0A, 0x40, 0x00, 0x21, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x23 };
 	char *fldname = vr->folder;
 	char varname[40] = "a1234567";
-	DUSBCalcParam *param;
-	DUSBCalcAttr **attrs;
+	CalcParam *param;
+	CalcAttr **attrs;
 	const int nattrs = 4;
 	char *utf8;
 
@@ -830,29 +755,30 @@ static int		new_folder  (CalcHandle* handle, VarRequest* vr)
 	update_label();
 
 	// send empty expression in specified folder
-	attrs = dusb_ca_new_array(nattrs);
-	attrs[0] = dusb_ca_new(AID_VAR_TYPE, 4);
+	attrs = ca_new_array(nattrs);
+	attrs[0] = ca_new(AID_VAR_TYPE, 4);
 	attrs[0]->data[0] = 0xF0; attrs[0]->data[1] = 0x0C;
 	attrs[0]->data[2] = 0x00; attrs[0]->data[3] = 0x00;
-	attrs[1] = dusb_ca_new(AID_ARCHIVED, 1);
+	attrs[1] = ca_new(AID_ARCHIVED, 1);
 	attrs[1]->data[0] = 0;
-	attrs[2] = dusb_ca_new(AID_VAR_VERSION, 4);
+	attrs[2] = ca_new(AID_VAR_VERSION, 4);
 	attrs[2]->data[0] = 0;
-	attrs[3] = dusb_ca_new(AID_LOCKED, 1);
+	attrs[3] = ca_new(AID_LOCKED, 1);
 	attrs[3]->data[0] = 0;
 
-	TRYF(dusb_cmd_s_rts(handle, fldname, varname, sizeof(data), nattrs, CA(attrs)));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	TRYF(dusb_cmd_s_var_content(handle, sizeof(data), data));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	TRYF(dusb_cmd_s_eot(handle));
+	TRYF(cmd_s_rts(handle, fldname, varname, sizeof(data), 
+		       nattrs, CA(attrs)));
+	TRYF(cmd_r_data_ack(handle));
+	TRYF(cmd_s_var_content(handle, sizeof(data), data));
+	TRYF(cmd_r_data_ack(handle));
+	TRYF(cmd_s_eot(handle));
 
 	// go back to HOME screen
-	param = dusb_cp_new(PID_HOMESCREEN, 1);
+	param = cp_new(PID_HOMESCREEN, 1);
 	param->data[0] = 1;
-	TRYF(dusb_cmd_s_param_set(handle, param));
-	TRYF(dusb_cmd_r_data_ack(handle));
-	dusb_cp_del(param);
+	TRYF(cmd_s_param_set(handle, param));
+	TRYF(cmd_r_data_ack(handle));
+	cp_del(param);
 
 	// delete 'a1234567' variable
 	strcpy(vr->name, "a1234567");
@@ -876,21 +802,21 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	};	// Titanium can't manage more than 16 parameters at a time
 	const int size1 = sizeof(pids1) / sizeof(uint16_t);
 	const int size2 = sizeof(pids2) / sizeof(uint16_t);
-	DUSBCalcParam **params1;
-	DUSBCalcParam **params2;
+	CalcParam **params1;
+	CalcParam **params2;
 	int i = 0;
 
 	g_snprintf(update_->text, sizeof(update_->text), _("Getting version..."));
 	update_label();
 
 	memset(infos, 0, sizeof(CalcInfos));
-	params1 = dusb_cp_new_array(size1);
-	params2 = dusb_cp_new_array(size2);
+	params1 = cp_new_array(size1);
+	params2 = cp_new_array(size2);
 
-	TRYF(dusb_cmd_s_param_request(handle, size1, pids1));
-	TRYF(dusb_cmd_r_param_data(handle, size1, params1));
-	TRYF(dusb_cmd_s_param_request(handle, size2, pids2));
-	TRYF(dusb_cmd_r_param_data(handle, size2, params2));
+	TRYF(cmd_s_param_request(handle, size1, pids1));
+	TRYF(cmd_r_param_data(handle, size1, params1));
+	TRYF(cmd_s_param_request(handle, size2, pids2));
+	TRYF(cmd_r_param_data(handle, size2, params2));
 
 	strncpy(infos->product_name, (char *)params1[i]->data, params1[i]->size);
 	infos->mask |= INFOS_PRODUCT_NAME;
@@ -929,82 +855,30 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	infos->mask |= INFOS_OS_VERSION;
 	i++;
 
-	//infos->ram_phys = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->ram_phys = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                   | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                   | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                   | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                   | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                   | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                   | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                   | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->ram_phys = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_RAM_PHYS;
 	i++;
-	//infos->ram_user = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->ram_user = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                   | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                   | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                   | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                   | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                   | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                   | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                   | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->ram_user = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_RAM_USER;
 	i++;
-	//infos->ram_free = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->ram_free = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                   | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                   | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                   | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                   | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                   | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                   | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                   | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->ram_free = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_RAM_FREE;
 	i++;
 
-	//infos->flash_phys = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->flash_phys = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                     | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                     | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                     | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                     | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                     | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                     | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                     | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->flash_phys = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_FLASH_PHYS;
 	i++;
-	//infos->flash_user = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->flash_user = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                     | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                     | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                     | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                     | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                     | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                     | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                     | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->flash_user = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_FLASH_USER;
 	i++;
-	//infos->flash_free = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
-	infos->flash_free = (  (((uint64_t)(params1[i]->data[ 0])) << 56)
-	                     | (((uint64_t)(params1[i]->data[ 1])) << 48)
-	                     | (((uint64_t)(params1[i]->data[ 2])) << 40)
-	                     | (((uint64_t)(params1[i]->data[ 3])) << 32)
-	                     | (((uint64_t)(params1[i]->data[ 4])) << 24)
-	                     | (((uint64_t)(params1[i]->data[ 5])) << 16)
-	                     | (((uint64_t)(params1[i]->data[ 6])) <<  8)
-	                     | (((uint64_t)(params1[i]->data[ 7]))      ));
+	infos->flash_free = GINT64_FROM_BE(*((uint64_t *)(params1[i]->data)));
 	infos->mask |= INFOS_FLASH_FREE;
 	i++;
 
-	//infos->lcd_width = GINT16_FROM_BE(*((uint16_t *)(params1[i]->data)));
-	infos->lcd_width = (  (((uint16_t)params1[i]->data[ 0]) <<  8)
-	                    | (((uint16_t)params1[i]->data[ 1])      ));
+	infos->lcd_width = GINT16_FROM_BE(*((uint16_t *)(params1[i]->data)));
 	infos->mask |= INFOS_LCD_WIDTH;
 	i++;
-	//infos->lcd_height = GINT16_FROM_BE(*((uint16_t *)(params1[i]->data)));
-	infos->lcd_height = (  (((uint16_t)params1[i]->data[ 0]) <<  8)
-	                     | (((uint16_t)params1[i]->data[ 1])      ));
+	infos->lcd_height = GINT16_FROM_BE(*((uint16_t *)(params1[i]->data)));
 	infos->mask |= INFOS_LCD_HEIGHT;
 	i++;
 
@@ -1023,8 +897,8 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 	infos->model = CALC_TI89T;
 	infos->mask |= INFOS_CALC_MODEL;
 
-	dusb_cp_del_array(size1, params1);
-	dusb_cp_del_array(size2, params2);
+	cp_del_array(size1, params1);
+	cp_del_array(size2, params2);
 	return 0;
 }
 
@@ -1048,10 +922,9 @@ const CalcFncts calc_89t_usb =
 	N_("TI-89 Titanium thru DirectLink"),
 	OPS_ISREADY | OPS_SCREEN | OPS_DIRLIST | OPS_VARS | OPS_FLASH | OPS_OS | OPS_ROMDUMP |
 	OPS_IDLIST | OPS_CLOCK | OPS_DELVAR | OPS_NEWFLD | OPS_VERSION | OPS_BACKUP | OPS_KEYS |
-	OPS_RENAME | OPS_CHATTR |
 	FTS_SILENT | FTS_MEMFREE | FTS_FLASH | FTS_FOLDER,
 	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
-		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L", "", "" },
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1077,6 +950,4 @@ const CalcFncts calc_89t_usb =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
