@@ -35,7 +35,6 @@
 
 #include <ticonv.h>
 #include "ticalcs.h"
-#include "internal.h"
 #include "gettext.h"
 #include "logging.h"
 #include "error.h"
@@ -86,7 +85,7 @@ static int		is_ready	(CalcHandle* handle)
 			ticalcs_info("  waiting for LOGIN request (OS >= 1.2 check)...");
 			old = ticables_options_set_timeout(handle->cable, 40);	// 3s mini
 
-			ret = nsp_cmd_r_login(handle);	// no call to TRYF(nsp_send_nack(handle)) because nack is managed in nsp_recv_data()
+			ret = cmd_r_login(handle);	// no call to TRYF(nsp_send_nack(handle)) because nack is managed in nsp_recv_data()
 
 			ticables_options_set_timeout(handle->cable, old);
 			if(ret)
@@ -125,8 +124,8 @@ static int		is_ready	(CalcHandle* handle)
 
 		TRYF(nsp_session_open(handle, SID_ECHO));
 
-		TRYF(nsp_cmd_s_echo(handle, strlen(str)+1, (uint8_t *)str));
-		TRYF(nsp_cmd_r_echo(handle, &size, &data));
+		TRYF(cmd_s_echo(handle, strlen(str)+1, (uint8_t *)str));
+		TRYF(cmd_r_echo(handle, &size, &data));
 		g_free(data);
 
 		TRYF(nsp_session_close(handle));
@@ -195,14 +194,12 @@ static uint8_t* rle_uncompress(CalcScreenCoord* sc, const uint8_t *src, uint32_t
 			{
 				// Positive count: "repeat 32-bit value" block.
 				uint8_t cnt = ((uint8_t)rec) + 1;
-				uint32_t val;
-				uint8_t j;
+				uint32_t val = *(uint32_t *)(src + i);
 
-				memcpy(&val, src + i, sizeof(uint32_t));
+				uint8_t j = 0;
 				for (j = 0; j < cnt; j++)
 				{
-					//*((uint32_t *)q) = val;
-					memcpy(q, &val, 4);
+					*((uint32_t *)q) = val;
 					q += 4;
 				}
 				i += 4;
@@ -212,7 +209,7 @@ static uint8_t* rle_uncompress(CalcScreenCoord* sc, const uint8_t *src, uint32_t
 				// Negative count: "verbatim" block of 32-bit values.
 				uint8_t cnt = ((uint8_t)-rec) + 1;
 
-				memcpy(q, src + i, cnt * 4);
+				memcpy(q, src+i, cnt * 4);
 				q += cnt * 4;
 				i += cnt * 4;
 			}
@@ -256,16 +253,12 @@ static int		recv_screen	(CalcHandle* handle, CalcScreenCoord* sc, uint8_t** bitm
 		// Do screenshot
 		TRYF(nsp_session_open(handle, SID_SCREEN_RLE));
 
-		TRYF(nsp_cmd_s_screen_rle(handle, 0));
-		TRYF(nsp_cmd_r_screen_rle(handle, &cmd, &size, &data));
+		TRYF(cmd_s_screen_rle(handle, 0));
+		TRYF(cmd_r_screen_rle(handle, &cmd, &size, &data));
 		sc->width = sc->clipped_width = (data[8] << 8) | data[9];
 		sc->height = sc->clipped_height = (data[10] << 8) | data[11];
-		//size = GUINT32_FROM_BE(*((uint32_t *)(data)));
-		size = (  (((uint32_t)data[0]) << 24)
-		        | (((uint32_t)data[1]) << 16)
-		        | (((uint32_t)data[2]) <<  8)
-		        | (((uint32_t)data[3])      ));
-		TRYF(nsp_cmd_r_screen_rle(handle, &cmd, &size, &data));
+		size = GUINT32_FROM_BE(*((uint32_t *)(data)));
+		TRYF(cmd_r_screen_rle(handle, &cmd, &size, &data));
 
 		TRYF(nsp_session_close(handle));
 
@@ -309,22 +302,22 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 	g_node_append(*apps, root);
 
 	TRYF(nsp_session_open(handle, SID_FILE_MGMT));
-	TRYF(nsp_cmd_s_dir_attributes(handle, "/"));
-	TRYF(nsp_cmd_r_dir_attributes(handle, NULL, NULL, NULL));
+	TRYF(cmd_s_dir_attributes(handle, "/"));
+	TRYF(cmd_r_dir_attributes(handle, NULL, NULL, NULL));
 	TRYF(nsp_session_close(handle));
 
 	TRYF(nsp_session_open(handle, SID_FILE_MGMT));
 
-	TRYF(nsp_cmd_s_dir_enum_init(handle, "/"));
-	TRYF(nsp_cmd_r_dir_enum_init(handle));
+	TRYF(cmd_s_dir_enum_init(handle, "/"));
+	TRYF(cmd_r_dir_enum_init(handle));
 
 	for(;;)
 	{
 		VarEntry *fe;
 		GNode *node;
 
-		TRYF(nsp_cmd_s_dir_enum_next(handle));
-		err = nsp_cmd_r_dir_enum_next(handle, varname, &varsize, &vartype);
+		TRYF(cmd_s_dir_enum_next(handle));
+		err = cmd_r_dir_enum_next(handle, varname, &varsize, &vartype);
 
 		if (err == ERR_EOT)
 			break;
@@ -348,8 +341,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 			fe->size);
 	}
 
-	TRYF(nsp_cmd_s_dir_enum_done(handle));
-	TRYF(nsp_cmd_r_dir_enum_done(handle));
+	TRYF(cmd_s_dir_enum_done(handle));
+	TRYF(cmd_r_dir_enum_done(handle));
 
 	for(i = 0; i < (int)g_node_n_children(*vars); i++) 
 	{
@@ -369,8 +362,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 
 		ticalcs_info(_("Directory listing in <%s>..."), folder_name);
 
-		TRYF(nsp_cmd_s_dir_enum_init(handle, folder_name));
-		TRYF(nsp_cmd_r_dir_enum_init(handle));
+		TRYF(cmd_s_dir_enum_init(handle, folder_name));
+		TRYF(cmd_r_dir_enum_init(handle));
 
 		for(;;)
 		{
@@ -378,8 +371,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 			GNode *node;
 			char *ext;
 
-			TRYF(nsp_cmd_s_dir_enum_next(handle));
-			err = nsp_cmd_r_dir_enum_next(handle, varname, &varsize, &vartype);
+			TRYF(cmd_s_dir_enum_next(handle));
+			err = cmd_r_dir_enum_next(handle, varname, &varsize, &vartype);
 
 			if (err == ERR_EOT)
 				break;
@@ -425,8 +418,8 @@ static int		get_dirlist	(CalcHandle* handle, GNode** vars, GNode** apps)
 			update_label();
 		}
 
-		TRYF(nsp_cmd_s_dir_enum_done(handle));
-		TRYF(nsp_cmd_r_dir_enum_done(handle));
+		TRYF(cmd_s_dir_enum_done(handle));
+		TRYF(cmd_r_dir_enum_done(handle));
 	}
 
 	TRYF(nsp_session_close(handle));
@@ -438,26 +431,18 @@ static int		get_memfree	(CalcHandle* handle, uint32_t* ram, uint32_t* flash)
 {
 	uint32_t size;
 	uint8_t cmd, *data;
-	//int i;
+	int i;
 
 	TRYF(nsp_session_open(handle, SID_DEV_INFOS));
 
-	TRYF(nsp_cmd_s_dev_infos(handle, CMD_DI_VERSION));
-	TRYF(nsp_cmd_r_dev_infos(handle, &cmd, &size, &data));
+	TRYF(cmd_s_dev_infos(handle, CMD_DI_VERSION));
+	TRYF(cmd_r_dev_infos(handle, &cmd, &size, &data));
 
-	//i = 0;
-	//*flash = (uint32_t)GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	*flash = (  (((uint32_t)data[4]) << 24)
-	          | (((uint32_t)data[5]) << 16)
-	          | (((uint32_t)data[6]) <<  8)
-	          | (((uint32_t)data[7])      ));
+	i = 0;
+	*flash = (uint32_t)GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 
-	//i = 16;
-	//*ram = (uint32_t)GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	*ram = (  (((uint32_t)data[20]) << 24)
-	        | (((uint32_t)data[21]) << 16)
-	        | (((uint32_t)data[22]) <<  8)
-	        | (((uint32_t)data[23])      ));
+	i = 16;
+	*ram = (uint32_t)GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 
 	g_free(data);
 	TRYF(nsp_session_close(handle));
@@ -500,16 +485,16 @@ static int		send_var	(CalcHandle* handle, CalcMode mode, FileContent* content)
 		g_free(utf8);
 		update_label();
 
-		err = nsp_cmd_s_put_file(handle, path, ve->size);
+		err = cmd_s_put_file(handle, path, ve->size);
 		g_free(path);
 		if (err)
 		{
 			return err;
 		}
-		TRYF(nsp_cmd_r_put_file(handle));
+		TRYF(cmd_r_put_file(handle));
 
-		TRYF(nsp_cmd_s_file_contents(handle, ve->size, ve->data));
-		TRYF(nsp_cmd_r_status(handle, &status));
+		TRYF(cmd_s_file_contents(handle, ve->size, ve->data));
+		TRYF(cmd_r_status(handle, &status));
 
 		TRYF(nsp_session_close(handle));
 	}
@@ -539,18 +524,18 @@ static int		recv_var	(CalcHandle* handle, CalcMode mode, FileContent* content, V
 	g_free(utf8);
 	update_label();
 
-	err = nsp_cmd_s_get_file(handle, path);
+	err = cmd_s_get_file(handle, path);
 	g_free(path);
 	if (err)
 	{
 		return err;
 	}
-	TRYF(nsp_cmd_r_get_file(handle, &(vr->size)));
+	TRYF(cmd_r_get_file(handle, &(vr->size)));
 
-	TRYF(nsp_cmd_s_file_ok(handle));
+	TRYF(cmd_s_file_ok(handle));
 	if (vr->size)
-		TRYF(nsp_cmd_r_file_contents(handle, &(vr->size), &data));
-	TRYF(nsp_cmd_s_status(handle, ERR_OK));
+		TRYF(cmd_r_file_contents(handle, &(vr->size), &data));
+	TRYF(cmd_s_status(handle, ERR_OK));
 
 	content->model = handle->model;
 	strcpy(content->comment, tifiles_comment_set_single());
@@ -614,12 +599,12 @@ static int		send_os    (CalcHandle* handle, FlashContent* content)
 
 	TRYF(nsp_session_open(handle, SID_OS_INSTALL));
 
-	TRYF(nsp_cmd_s_os_install(handle, content->data_length));
-	TRYF(nsp_cmd_r_os_install(handle));
+	TRYF(cmd_s_os_install(handle, content->data_length));
+	TRYF(cmd_r_os_install(handle));
 
-	TRYF(nsp_cmd_s_os_contents(handle, 253, content->data_part));
-	TRYF(nsp_cmd_r_status(handle, &status));
-	TRYF(nsp_cmd_s_os_contents(handle, content->data_length - 253, content->data_part + 253));
+	TRYF(cmd_s_os_contents(handle, 253, content->data_part));
+	TRYF(cmd_r_status(handle, &status));
+	TRYF(cmd_s_os_contents(handle, content->data_length - 253, content->data_part + 253));
 
 	update_->cnt2 = 0;
 	update_->max2 = 100;
@@ -627,7 +612,7 @@ static int		send_os    (CalcHandle* handle, FlashContent* content)
 
 	do
 	{
-		TRYF(nsp_cmd_r_progress(handle, &value));
+		TRYF(cmd_r_progress(handle, &value));
 
 		update_->cnt2 = value;
 		update_->pbar();
@@ -645,8 +630,8 @@ static int		recv_idlist	(CalcHandle* handle, uint8_t* id)
 
 	TRYF(nsp_session_open(handle, SID_DEV_INFOS));
 
-	TRYF(nsp_cmd_s_dev_infos(handle, CMD_DI_VERSION));
-	TRYF(nsp_cmd_r_dev_infos(handle, &cmd, &size, &data));
+	TRYF(cmd_s_dev_infos(handle, CMD_DI_VERSION));
+	TRYF(cmd_r_dev_infos(handle, &cmd, &size, &data));
 
 	strncpy((char *)id, (char*)(data + 82), 28);
 
@@ -668,7 +653,7 @@ static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filen
 	int err;
 	FILE *f;
 
-	ticalcs_info("FIXME: make ROM dumping work above OS 1.x");
+	ticalcs_info("FIXME: make ROM dumping work on OS 2.x");
 
 	TRYF(nsp_session_open(handle, SID_FILE_MGMT));
 
@@ -678,19 +663,19 @@ static int		dump_rom_2	(CalcHandle* handle, CalcDumpSize size, const char *filen
 		return ERR_OPEN_FILE;
 	}
 
-	err = nsp_cmd_s_get_file(handle, "../phoenix/install/TI-Nspire.tnc");
+	err = cmd_s_get_file(handle, "../phoenix/install/TI-Nspire.tnc");
 	if (!err)
 	{
-		err = nsp_cmd_r_get_file(handle, &varsize);
+		err = cmd_r_get_file(handle, &varsize);
 		if (!err)
 		{
-			err = nsp_cmd_s_file_ok(handle);
+			err = cmd_s_file_ok(handle);
 			if (!err)
 			{
-				err = nsp_cmd_r_file_contents(handle, &varsize, &data);
+				err = cmd_r_file_contents(handle, &varsize, &data);
 				if (!err)
 				{
-					err = nsp_cmd_s_status(handle, ERR_OK);
+					err = cmd_s_status(handle, ERR_OK);
 					if (!err)
 					{
 						if (fwrite(data, varsize, 1, f) < 1)
@@ -719,53 +704,6 @@ static int		get_clock	(CalcHandle* handle, CalcClock* _clock)
 	return 0;
 }
 
-static int		rename_var	(CalcHandle* handle, VarRequest* oldname, VarRequest* newname)
-{
-	char *utf81, *utf82;
-	char *path1, *path2;
-	int err;
-	const char * dot_if_any = ".";
-
-	TRYF(nsp_session_open(handle, SID_FILE_MGMT));
-
-	// Don't add a dot if this file type is unknown.
-	if (oldname->type >= NSP_MAXTYPES)
-		dot_if_any = "";
-	path1 = g_strconcat("/", oldname->folder, "/", oldname->name, dot_if_any,
-		tifiles_vartype2fext(handle->model, oldname->type), NULL);
-
-	dot_if_any = ".";
-	// Don't add a dot if this file type is unknown.
-	if (oldname->type >= NSP_MAXTYPES)
-		dot_if_any = "";
-	path2 = g_strconcat("/", newname->folder, "/", newname->name, dot_if_any,
-		tifiles_vartype2fext(handle->model, newname->type), NULL);
-	utf81 = ticonv_varname_to_utf8(handle->model, path1, oldname->type);
-	utf82 = ticonv_varname_to_utf8(handle->model, path2, newname->type);
-	g_snprintf(update_->text, sizeof(update_->text), _("Renaming %s to %s..."), utf81, utf82);
-	g_free(utf82);
-	g_free(utf81);
-	update_label();
-
-	err = nsp_cmd_s_rename_file(handle, path1, path2);
-	g_free(path2);
-	g_free(path1);
-	if (err)
-	{
-		return err;
-	}
-	TRYF(nsp_cmd_r_rename_file(handle));
-
-	TRYF(nsp_session_close(handle));
-
-	return 0;
-}
-
-static int		change_attr	(CalcHandle* handle, VarRequest* vr, FileAttr attr)
-{
-	return 0;
-}
-
 static int		del_var		(CalcHandle* handle, VarRequest* vr)
 {
 	char *utf8;
@@ -779,20 +717,20 @@ static int		del_var		(CalcHandle* handle, VarRequest* vr)
 	if (vr->type >= NSP_MAXTYPES)
 		dot_if_any = "";
 
-	path = g_strconcat("/", vr->folder, "/", vr->name, dot_if_any,
+	path = g_strconcat("/", vr->folder, "/", vr->name, dot_if_any, 
 		tifiles_vartype2fext(handle->model, vr->type), NULL);
 	utf8 = ticonv_varname_to_utf8(handle->model, path, vr->type);
 	g_snprintf(update_->text, sizeof(update_->text), _("Deleting %s..."), utf8);
 	g_free(utf8);
 	update_label();
 
-	err = nsp_cmd_s_del_file(handle, path);
+	err = cmd_s_del_file(handle, path);
 	g_free(path);
 	if (err)
 	{
 		return err;
 	}
-	TRYF(nsp_cmd_r_del_file(handle));
+	TRYF(cmd_r_del_file(handle));
 
 	TRYF(nsp_session_close(handle));
 
@@ -813,13 +751,13 @@ static int		new_folder  (CalcHandle* handle, VarRequest* vr)
 	g_free(utf8);
 	update_label();
 
-	err = nsp_cmd_s_new_folder(handle, path);
+	err = cmd_s_new_folder(handle, path);
 	g_free(path);
 	if (err)
 	{
 		return err;
 	}
-	TRYF(nsp_cmd_r_new_folder(handle));
+	TRYF(cmd_r_new_folder(handle));
 
 	TRYF(nsp_session_close(handle));
 
@@ -830,135 +768,92 @@ static int		get_version	(CalcHandle* handle, CalcInfos* infos)
 {
 	uint32_t size;
 	uint8_t cmd, *data;
-	//int i;
+	int i;
 
 	TRYF(nsp_session_open(handle, SID_DEV_INFOS));
 
-	TRYF(nsp_cmd_s_dev_infos(handle, CMD_DI_MODEL));
-	TRYF(nsp_cmd_r_dev_infos(handle, &cmd, &size, &data));
+	TRYF(cmd_s_dev_infos(handle, CMD_DI_MODEL));
+	TRYF(cmd_r_dev_infos(handle, &cmd, &size, &data));
 
 	strcpy(infos->product_name, (char*)data);
 	infos->mask |= INFOS_PRODUCT_NAME;
 
-	TRYF(nsp_cmd_s_dev_infos(handle, CMD_DI_VERSION));
-	TRYF(nsp_cmd_r_dev_infos(handle, &cmd, &size, &data));
+	TRYF(cmd_s_dev_infos(handle, CMD_DI_VERSION));
+	TRYF(cmd_r_dev_infos(handle, &cmd, &size, &data));
 
 	infos->model = CALC_NSPIRE;
 
-	//i = 0;
-	//infos->flash_free = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	infos->flash_free = (  (((uint64_t)data[ 0]) << 56)
-	                     | (((uint64_t)data[ 1]) << 48)
-	                     | (((uint64_t)data[ 2]) << 40)
-	                     | (((uint64_t)data[ 3]) << 32)
-	                     | (((uint64_t)data[ 4]) << 24)
-	                     | (((uint64_t)data[ 5]) << 16)
-	                     | (((uint64_t)data[ 6]) <<  8)
-	                     | (((uint64_t)data[ 7])      ));
+	i = 0;
+	infos->flash_free = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 	infos->mask |= INFOS_FLASH_FREE;
 
-	//i = 8;
-	//infos->flash_phys = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	infos->flash_phys = (  (((uint64_t)data[ 8]) << 56)
-	                     | (((uint64_t)data[ 9]) << 48)
-	                     | (((uint64_t)data[10]) << 40)
-	                     | (((uint64_t)data[11]) << 32)
-	                     | (((uint64_t)data[12]) << 24)
-	                     | (((uint64_t)data[13]) << 16)
-	                     | (((uint64_t)data[14]) <<  8)
-	                     | (((uint64_t)data[15])      ));
+	i = 8;
+	infos->flash_phys = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 	infos->mask |= INFOS_FLASH_PHYS;
 
-	//i = 16;
-	//infos->ram_free = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	infos->ram_free = (  (((uint64_t)data[16]) << 56)
-	                   | (((uint64_t)data[17]) << 48)
-	                   | (((uint64_t)data[18]) << 40)
-	                   | (((uint64_t)data[19]) << 32)
-	                   | (((uint64_t)data[20]) << 24)
-	                   | (((uint64_t)data[21]) << 16)
-	                   | (((uint64_t)data[22]) <<  8)
-	                   | (((uint64_t)data[23])      ));
+	i = 16;
+	infos->ram_free = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 	infos->mask |= INFOS_RAM_FREE;
 
-	//i = 24;
-	//infos->ram_phys = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
-	infos->ram_phys = (  (((uint64_t)data[24]) << 56)
-	                   | (((uint64_t)data[25]) << 48)
-	                   | (((uint64_t)data[26]) << 40)
-	                   | (((uint64_t)data[27]) << 32)
-	                   | (((uint64_t)data[28]) << 24)
-	                   | (((uint64_t)data[29]) << 16)
-	                   | (((uint64_t)data[30]) <<  8)
-	                   | (((uint64_t)data[31])      ));
+	i = 24;
+	infos->ram_phys = GUINT64_FROM_BE(*((uint64_t *)(data + i)));
 	infos->mask |= INFOS_RAM_PHYS;
-
-	//i = 32;
-	infos->battery = (data[32] == 0x01) ? 0 : 1;
+	
+	i = 32;
+	infos->battery = (data[i] == 0x01) ? 0 : 1;
 	infos->mask |= INFOS_BATTERY;
 
-	//i = 35;
-	infos->clock_speed = data[35];
+	i = 35;
+	infos->clock_speed = data[i];
 	infos->mask |= INFOS_CLOCK_SPEED;
 
-	//i = 36;
+	i = 36;
 	g_snprintf(infos->os_version, sizeof(infos->os_version), "%1i.%1i.%04i",
-		data[36], data[37], (data[38] << 8) | data[39]);
+		data[i+0], data[i+1], (data[i+2] << 8) | data[i+3]);
 	infos->mask |= INFOS_OS_VERSION;
 
-	//i = 40;
+	i = 40;
 	g_snprintf(infos->boot_version, sizeof(infos->boot_version), "%1i.%1i.%04i",
-		data[40], data[41], (data[42] << 8) | data[43]);
+		data[i+0], data[i+1], (data[i+2] << 8) | data[i+3]);
 	infos->mask |= INFOS_BOOT_VERSION;
 
-	//i = 44;
+	i = 44;
 	g_snprintf(infos->boot2_version, sizeof(infos->boot2_version), "%1i.%1i.%04i",
-		data[44], data[45], (data[46] << 8) | data[47]);
+		data[i+0], data[i+1], (data[i+2] << 8) | data[i+3]);
 	infos->mask |= INFOS_BOOT2_VERSION;
 
-	//i = 48;
-	//infos->hw_version = GUINT32_FROM_BE(*((uint32_t *)(data + i)));
-	infos->hw_version = (  (((uint32_t)data[48]) << 24)
-	                     | (((uint32_t)data[49]) << 16)
-	                     | (((uint32_t)data[50]) <<  8)
-	                     | (((uint32_t)data[51])      ));
+	i = 48;
+	infos->hw_version = GUINT32_FROM_BE(*((uint32_t *)(data + i)));
 	infos->mask |= INFOS_HW_VERSION;
 
-	//i = 52;
-	//infos->run_level = (uint8_t)GUINT16_FROM_BE(*((uint16_t *)(data + i)));
-	infos->run_level = data[53];
+	i = 52;
+	infos->run_level = (uint8_t)GUINT16_FROM_BE(*((uint16_t *)(data + i)));
 	infos->mask |= INFOS_RUN_LEVEL;
 
-	//i = 58;
-	//infos->lcd_width = GUINT16_FROM_BE(*((uint16_t *)(data + i)));
-	infos->lcd_width = (  (((uint16_t)data[58]) << 8)
-	                    | (((uint16_t)data[59])     ));
+	i = 58;
+	infos->lcd_width = GUINT16_FROM_BE(*((uint16_t *)(data + i)));
 	infos->mask |= INFOS_LCD_WIDTH;
 
-	//i = 60;
-	//infos->lcd_height = GUINT16_FROM_BE(*((uint16_t *)(data + i)));
-	infos->lcd_height = (  (((uint16_t)data[60]) << 8)
-	                     | (((uint16_t)data[61])     ));
+	i = 60;
+	infos->lcd_height = GUINT16_FROM_BE(*((uint16_t *)(data + i)));
 	infos->mask |= INFOS_LCD_HEIGHT;
 
-	//i = 62;
-	infos->bits_per_pixel = data[62];
+	i = 62;
+	infos->bits_per_pixel = data[i];
 	infos->mask |= INFOS_BPP;
 
-	//i = 64;
-	infos->device_type = data[64];
+	i = 64;
+	infos->device_type = data[i];
 	infos->mask |= INFOS_DEVICE_TYPE;
 
-	memset(infos->main_calc_id, 0, sizeof(infos->main_calc_id));
 	strncpy(infos->main_calc_id, (char*)(data + 82), 28);
 	infos->mask |= INFOS_MAIN_CALC_ID;
-	memset(infos->product_id, 0, sizeof(infos->product_id));
 	strncpy(infos->product_id, (char*)(data + 82), 28);
 	infos->mask |= INFOS_PRODUCT_ID;
 
 	g_free(data);
 	TRYF(nsp_session_close(handle));
-
+	
 	return 0;
 }
 
@@ -981,34 +876,9 @@ const CalcFncts calc_nsp =
 	"Nspire handheld",
 	N_("Nspire thru DirectLink"),
 	OPS_ISREADY | OPS_VERSION | OPS_SCREEN | OPS_IDLIST | OPS_DIRLIST | OPS_VARS | OPS_OS |
-	OPS_ROMDUMP | OPS_NEWFLD | OPS_DELVAR | OPS_RENAME | FTS_SILENT | FTS_MEMFREE | FTS_FOLDER,
-	{"",     /* is_ready */
-	 "",     /* send_key */
-	 "",     /* execute */
-	 "1P",   /* recv_screen */
-	 "1L",   /* get_dirlist */
-	 "",     /* get_memfree */
-	 "2P1L", /* send_backup */
-	 "2P1L", /* recv_backup */
-	 "2P1L", /* send_var */
-	 "1P1L", /* recv_var */
-	 "2P1L", /* send_var_ns */
-	 "1P1L", /* recv_var_ns */
-	 "2P1L", /* send_app */
-	 "2P1L", /* recv_app */
-	 "2P",   /* send_os */
-	 "1L",   /* recv_idlist */
-	 "2P",   /* dump_rom1 */
-	 "2P",   /* dump_rom2 */
-	 "",     /* set_clock */
-	 "",     /* get_clock */
-	 "1L",   /* del_var */
-	 "1L",   /* new_folder */
-	 "",     /* get_version */
-	 "1L",   /* send_cert */
-	 "1L",   /* recv_cert */
-	 "",     /* rename */
-	 ""      /* chattr */ },
+	OPS_ROMDUMP | OPS_NEWFLD | OPS_DELVAR | FTS_SILENT | FTS_MEMFREE | FTS_FOLDER,
+	{"", "", "1P", "1L", "", "2P1L", "2P1L", "2P1L", "1P1L", "2P1L", "1P1L", "2P1L", "2P1L",
+		"2P", "1L", "2P", "", "", "1L", "1L", "", "1L", "1L" },
 	&is_ready,
 	&send_key,
 	&execute,
@@ -1034,6 +904,4 @@ const CalcFncts calc_nsp =
 	&get_version,
 	&send_cert,
 	&recv_cert,
-	&rename_var,
-	&change_attr
 };
