@@ -19,18 +19,36 @@
  *  Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  */
 
-// /!\ NOTE: for this file, backwards compatibility will not necessarily be maintained as strongly as it is for ticalcs.h !
-
 #ifndef __DUSB_RPKT__
 #define __DUSB_RPKT__
 
 // Raw packet types
 
-#define DUSB_RPKT_BUF_SIZE_REQ   1
-#define DUSB_RPKT_BUF_SIZE_ALLOC 2
+#define RPKT_BUF_SIZE_REQ		1
+#define RPKT_BUF_SIZE_ALLOC		2
 
-#define DUSB_RPKT_VIRT_DATA      3
-#define DUSB_RPKT_VIRT_DATA_LAST 4
-#define DUSB_RPKT_VIRT_DATA_ACK  5
+#define RPKT_VIRT_DATA			3
+#define RPKT_VIRT_DATA_LAST		4
+#define RPKT_VIRT_DATA_ACK		5
+
+// Convenient structures
+
+#define PH_SIZE		(4+1)	// size + type
+
+typedef struct
+{
+	uint32_t	size;	// raw packet size
+	uint8_t		type;	// raw packet type
+
+	uint8_t		data[1023];	// raw packet data (should be allocated)
+} RawPacket;
+
+// Functions
+
+RawPacket*  raw_pkt_new(uint32_t size);
+void		raw_pkt_del(RawPacket* pkt);
+
+int dusb_send(CalcHandle* cable, RawPacket* pkt);
+int dusb_recv(CalcHandle* cable, RawPacket* pkt);
 
 #endif
