@@ -274,39 +274,39 @@ const OldCalcKeys_ TI92P_KEYS[] =
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
 /* 0xE0, 224 */
-  {"\xe0", "\xe0", 224, "\192", 192, "", 0, "", 0, "", 0}, /* agrave */
+  {"", "", 224, "\192", 192, "", 0, "", 0, "", 0},
   {"\225", "\225", 225, "\193", 193, "", 0, "", 0, "", 0},
-  {"\xe2", "\xe2", 226, "\194", 194, "", 0, "", 0, "", 0}, /* acirc */
+  {"", "", 226, "\194", 194, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"\xe4", "\xe4", 228, "\196", 196, "", 0, "", 0, "", 0}, /* auml */
+  {"", "", 228, "\196", 196, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"\xe7", "\xe7", 231, "\199", 199, "", 0, "", 0, "", 0}, /* ccedil */
-  {"\xe8", "\xe8", 232, "\200", 200, "", 0, "", 0, "", 0}, /* egrave */
-  {"\xe9", "\xe9", 233, "\201", 201, "", 0, "", 0, "", 0}, /* eacute */
-  {"\xea", "\xea", 234, "\202", 202, "", 0, "", 0, "", 0}, /* ecirc */
-  {"\xeb", "\xeb", 235, "\203", 203, "", 0, "", 0, "", 0}, /* euml */
+  {"", "", 231, "\199", 199, "", 0, "", 0, "", 0},
+  {"", "", 232, "\200", 200, "", 0, "", 0, "", 0},
+  {"", "", 233, "\201", 201, "", 0, "", 0, "", 0},
+  {"", "", 234, "\202", 202, "", 0, "", 0, "", 0},
+  {"", "", 235, "\203", 203, "", 0, "", 0, "", 0},
   {"\236", "\236", 236, "\204", 204, "", 0, "", 0, "", 0},
   {"\237", "\237", 237, "\205", 205, "", 0, "", 0, "", 0},
-  {"\xee", "\xee", 238, "\206", 206, "", 0, "", 0, "", 0}, /* icirc */
-  {"\xef", "\xef", 239, "\207", 207, "", 0, "", 0, "", 0}, /* iuml */
+  {"", "", 238, "\206", 206, "", 0, "", 0, "", 0},
+  {"", "", 239, "\207", 207, "", 0, "", 0, "", 0},
 /* 0xF0, 240-255 */
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"\xf1", "\xf1", 241, "\209", 209, "", 0, "", 0, "", 0}, /* ntilde */
+  {"", "", 241, "\209", 209, "", 0, "", 0, "", 0},
   {"\242", "\242", 242, "\210", 210, "", 0, "", 0, "", 0},
   {"\243", "\243", 243, "\211", 211, "", 0, "", 0, "", 0},
-  {"\xf4", "\xf4", 244, "\212", 212, "", 0, "", 0, "", 0}, /* ocirc */
-  {"\xf5", "\xf5", 245, "", 0, "", 0, "", 0, "", 0}, /* otilde */
-  {"\xf6", "\xf6", 246, "\214", 214, "", 0, "", 0, "", 0}, /* ouml */
+  {"", "", 244, "\212", 212, "", 0, "", 0, "", 0},
+  {"", "", 245, "", 0, "", 0, "", 0, "", 0},
+  {"", "", 246, "\214", 214, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"\xf9", "\xf9", 249, "\217", 217, "", 0, "", 0, "", 0}, /* ugrave */
+  {"", "", 249, "\217", 217, "", 0, "", 0, "", 0},
   {"\250", "\250", 250, "\221", 221, "", 0, "", 0, "", 0},
-  {"\xfb", "\xfb", 251, "\219", 219, "", 0, "", 0, "", 0}, /* ucirc */
-  {"\xfc", "\xfc", 252, "\220", 220, "", 0, "", 0, "", 0}, /* uuml */
+  {"", "", 251, "\219", 219, "", 0, "", 0, "", 0},
+  {"", "", 252, "\220", 220, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
-  {"\xff", "\xff", 255, "", 0, "", 0, "", 0, "", 0}, /* yuml */
+  {"", "", 255, "", 0, "", 0, "", 0, "", 0},
 /* 0x100, 256 */
   {"", "", 0, "", 0, "", 0, "", 0, "", 0},
   {"<-", "BS", 257, "BS", 257, "INS", 4353, "DEL", 8449, "", 0},
